
from django.contrib import admin

from stem_registration.models import RegistrationData


class RegistrationDataAdmin(admin.ModelAdmin):
    list_display = ['user', 'contractor_type', 'country', 'number', 'name_legal', ]
    search_fields = ['user__username', 'number', 'user__email']


admin.site.register(RegistrationData, RegistrationDataAdmin)



# Generated by Django 2.1.2 on 2018-10-22 13:58

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='RegistrationData',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('contractor_type', models.CharField(blank=True, choices=[('PP', 'Частное лицо'), ('CO', 'Компания'), ('IE', 'Частный предприниматель')], default='PP', help_text='<details><ul><li>Частное лицо: заполняем ФИО, ИНН - не обязательно. Наименование  = ФИО</li><li>Частный предприниматель: заполняем ФИО, ИНН, полное наименование. Наименование  = ФИО (СПД-ФЛ)</li><li>Компания: заполняем Наименование, Полное наименование, ИНН, ЕГРПОУ</li></ul></details>', max_length=2, verbose_name='Тип контрагента')),
                ('address', models.CharField(blank=True, default='', max_length=255, verbose_name='Адрес')),
                ('address_optional', models.CharField(blank=True, default='', max_length=255, verbose_name='Адрес (доп.)')),
                ('country', models.CharField(blank=True, default='', max_length=100, verbose_name='Страна')),
                ('city', models.CharField(blank=True, default='', max_length=100, verbose_name='Город')),
                ('zip', models.CharField(blank=True, default='', max_length=50, verbose_name='Почтовый индекс')),
                ('billing_address', models.CharField(blank=True, default='', max_length=255, verbose_name='Адрес')),
                ('bill_address_optional', models.CharField(blank=True, default='', max_length=255, verbose_name='Адрес')),
                ('bill_city', models.CharField(blank=True, default='', max_length=100, verbose_name='Город')),
                ('bill_zip', models.CharField(blank=True, default='', max_length=50, verbose_name='Почтовый индекс')),
                ('number', models.CharField(blank=True, default='', max_length=50, verbose_name='Номер телефона')),
                ('tax_number', models.CharField(blank=True, default='', max_length=12, verbose_name='ИНН')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from cities_light.models import Country
from django.conf import settings
from django.contrib.auth.models import User
from django.core.exceptions import ValidationError
from django_select2.forms import ModelSelect2Widget
from registration.forms import RegistrationFormUniqueEmail

from django import forms
from django.utils.translation import ugettext as _

from stem_registration.models import RegistrationData


class RegistrationDataForm(forms.ModelForm):
    class Meta:
        model = RegistrationData
        fields = '__all__'


class RegistrationForm(RegistrationFormUniqueEmail):
    class Meta:
        model = User
        fields = (
            'username', 'first_name', 'last_name', 'email', 'password1', 'password2',
        )

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        registration_form_fields = RegistrationDataForm().fields
        if not getattr(settings, 'SHOW_LOGIN', True):
            self.fields['username'].required = False

        if not getattr(settings, 'SHOW_LAST_FIRST_NAME', True):
            # Делаем поля скрытыми
            self.fields['first_name'].widget = forms.HiddenInput()
            self.fields['last_name'].widget = forms.HiddenInput()

        if getattr(settings, 'SHOW_CONTRACTOR_TYPE', True):
            self.fields['contractor_type'] = forms.ChoiceField(
                required=False,
                choices=RegistrationData.CONTRACTOR_TYPE,
                widget=forms.RadioSelect(),
                label=_("Компания"), initial=RegistrationData.PRIVATE_PERSON
            )

        _show_address = getattr(settings, 'SHOW_ADDRESS', True)
        if _show_address:
            self.fields['address'] = registration_form_fields['address']
            self.fields['address'].required = True
            self.fields['address_optional'] = registration_form_fields['address_optional']
            self.fields['city'] = registration_form_fields['city']
            self.fields['country'] = registration_form_fields['country']
            self.fields['country'].widget = ModelSelect2Widget(
                    model=Country,
                    search_fields=['name__icontains'],
                    attrs={'data-placeholder': _("Страна"), },
                )
            self.initial['country'] = Country.objects.get(code3=getattr(settings, 'DEFAULT_COUNTRY', 'UKR'))
            # self.fields['country'].initial = Country.objects.get(code3=getattr(settings, 'DEFAULT_COUNTRY', 'UKR'))
            self.fields['zip'] = registration_form_fields['zip']

        _show_billing_address = getattr(settings, 'SHOW_BILLING_ADDRESS', True)
        if _show_billing_address:
            if _show_address:
                self.fields['same'] = forms.BooleanField(
                    widget=forms.CheckboxInput(), label=_("Same"),
                    required=False, initial=True
                )

            self.fields['billing_address'] = registration_form_fields['billing_address']
            self.fields['bill_address_optional'] = registration_form_fields['bill_address_optional']
            self.fields['bill_city'] = registration_form_fields['bill_city']
            self.fields['bill_zip'] = registration_form_fields['bill_zip']
            self.fields['bill_country'] = registration_form_fields['bill_country']
            self.fields['bill_country'].widget = ModelSelect2Widget(
                model=Country,
                search_fields=['name__icontains'],
                attrs={'data-placeholder': _("Страна"), 'data-width': '10em'},
            )
            self.fields['bill_country'].initial = Country.objects.get(code3=getattr(settings, 'DEFAULT_COUNTRY', 'UKR'))

        if getattr(settings, 'SHOW_NUMBER', True):
            self.fields['number'] = registration_form_fields['number']
            self.fields['number'].required = getattr(settings, 'NUMBER_IS_REQUIRED', True)

        if getattr(settings, 'SHOW_TAX_NUMBER', True):
            self.fields['tax_number'] = registration_form_fields['tax_number']
            self.fields['tax_number'].required = getattr(settings, 'TAX_NUMBER_IS_REQUIRED', True)

        if getattr(settings, 'SHOW_ID_CARD_FIELDS', True):
            for field in ('file1', 'file2', 'file3', 'file4', 'file5'):
                self.fields[field] = registration_form_fields[field]
                self.fields[field].widget = forms.FileInput(attrs={'class': 'd-none file'})

        if getattr(settings, 'SHOW_NAME_LEGAL', True):
            self.fields['name_legal'] = registration_form_fields['name_legal']
            self.fields['name_legal'].required = getattr(settings, 'NAME_LEGAL_IS_REQUIRED', False)

        if getattr(settings, 'SHOW_ACCOUNTING_NUMBER', True):
            self.fields['accounting_number'] = registration_form_fields['accounting_number']
            # self.fields['accounting_number'] = CharField(max_length=30, label=_("ЕГРПОУ"), required=False)

    def save(self, commit=True):
        user = super(RegistrationForm, self).save(commit=False)

        user.is_active = False

        if user.username == '':
            user.username = user.email

        user.save()

        fields = (
            'contractor_type',
            'address',
            'address_optional',
            'country',
            'city',
            'zip',
            'billing_address',
            'bill_address_optional',
            'bill_city',
            'bill_zip',
            'number',
            'tax_number',
            'country',
            'bill_country',
            'name_legal',
            'accounting_number',
            'file1', 'file2', 'file3', 'file4', 'file5',
        )

        registration_data = {}
        for item in self.cleaned_data:
            if item in fields:
                registration_data[item] = self.cleaned_data[item]

        RegistrationData.objects.create(user=user, **registration_data)

        if commit:
            user.save()
            return user

    def clean(self):
        if getattr(self, 'tax_number', '') != '' and getattr(self, 'contractor_type', False):
            if (self.contractor_type == self.PRIVATE_PERSON or self.contractor_type == self.INDIVIDUAL_ENTREPRENEUR) \
                    and len(self.tax_number) != 10:
                raise ValidationError(_("ИНН должен содержать 10 символов"))
            elif self.contractor_type == self.COMPANY and len(self.tax_number) != 12:
                raise ValidationError(_("ИНН должен содержать 12 символов"))



# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2018-11-15 14:26
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('stem_registration', '0005_auto_20181112_1728'),
    ]

    operations = [
        migrations.AlterField(
            model_name='registrationdata',
            name='bill_address_optional',
            field=models.CharField(blank=True, default='', max_length=255, verbose_name='Адрес доставки доп.'),
        ),
        migrations.AlterField(
            model_name='registrationdata',
            name='bill_city',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='Город доставки'),
        ),
        migrations.AlterField(
            model_name='registrationdata',
            name='bill_country',
            field=models.ForeignKey(blank=True, help_text='Страна доставки', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='bill_countries', to='cities_light.Country', verbose_name='Страна доставки'),
        ),
        migrations.AlterField(
            model_name='registrationdata',
            name='bill_zip',
            field=models.CharField(blank=True, default='', max_length=50, verbose_name='Почтовый индекс доставки'),
        ),
        migrations.AlterField(
            model_name='registrationdata',
            name='billing_address',
            field=models.CharField(blank=True, default='', max_length=255, verbose_name='Адрес доставки'),
        ),
    ]



from django.contrib.auth.models import User
from django.core.exceptions import ValidationError
from django.utils.translation import ugettext_lazy as _
from django.db import models


class RegistrationData(models.Model):
    PRIVATE_PERSON = 'PP'
    COMPANY = 'CO'
    INDIVIDUAL_ENTREPRENEUR = 'IE'
    CONTRACTOR_TYPE = (
        (PRIVATE_PERSON, _('Частное лицо')),
        (COMPANY, _('Компания')),
        (INDIVIDUAL_ENTREPRENEUR, _('Частный предприниматель'))
    )

    user = models.OneToOneField(User, on_delete=models.CASCADE)
    contractor_type = models.CharField(
        max_length=2, choices=CONTRACTOR_TYPE, default=PRIVATE_PERSON, null=False,
        verbose_name=_('Тип контрагента'),
        help_text=_(
            '<details>'
            '<ul>'
            '<li>Частное лицо: заполняем ФИО, ИНН - не обязательно. Наименование  = ФИО</li>'
            '<li>Частный предприниматель: заполняем ФИО, ИНН, полное наименование. Наименование  = ФИО (СПД-ФЛ)</li>'
            '<li>Компания: заполняем Наименование, Полное наименование, ИНН, ЕГРПОУ</li>'
            '</ul>'
            '</details>'
        ),
        blank=True,
    )

    address = models.CharField(max_length=255, default='', blank=True, verbose_name=_('Адрес'))
    address_optional = models.CharField(max_length=255, default='', blank=True, verbose_name=_('Адрес (доп.)'))
    country = models.ForeignKey(
        'cities_light.Country', on_delete=models.SET_NULL, null=True,
        verbose_name=_('Страна'), blank=True,
        help_text=_('Страна происхождения контрагента')
    )
    city = models.CharField(max_length=100, default='', blank=True, verbose_name=_('Город'))
    zip = models.CharField(max_length=50, default='', blank=True, verbose_name=_('Почтовый индекс'))
    # same = forms.BooleanField(widget=forms.CheckboxInput(), label=_("Same"),
    #                           required=False, initial=True)
    billing_address = models.CharField(max_length=255, default='', blank=True, verbose_name=_('Адрес доставки'))
    bill_address_optional = models.CharField(
        max_length=255, default='', blank=True, verbose_name=_('Адрес доставки доп.')
    )
    bill_city = models.CharField(max_length=100, default='', blank=True, verbose_name=_('Город доставки'))
    bill_zip = models.CharField(max_length=50, default='', blank=True, verbose_name=_('Почтовый индекс доставки'))
    bill_country = models.ForeignKey(
        'cities_light.Country', on_delete=models.SET_NULL, null=True,
        verbose_name=_('Страна доставки'), blank=True,
        help_text=_('Страна доставки'),
        related_name='bill_countries',
    )

    number = models.CharField(max_length=50, default='', blank=True, verbose_name=_('Номер телефона'))

    accounting_number = models.CharField(
        max_length=20, default='', blank=True, null=True,
        verbose_name=_('ЕГРПОУ'),
        help_text=_(
            '<details>для других страни или не используется или как-то иначе называется</details>')
    )

    name_legal = models.CharField(
        max_length=255, default='', blank=True,
        verbose_name=_('Полное наименование'),
        help_text=_('<details>Юридическое название компании, '
                    'частного или индивидуального предпринимателя.'
                    '<br>Для Частный лиц указывайте ФИО полностью'
                    '<br>Это поле используется при формировании печатных форм документов</details>')
    )
    tax_number = models.CharField(default='', max_length=12, blank=True, verbose_name=_('ИНН'))

    file1 = models.ImageField(upload_to='clients_data/', blank=True)
    file2 = models.ImageField(upload_to='clients_data/', blank=True)
    file3 = models.ImageField(upload_to='clients_data/', blank=True)
    file4 = models.ImageField(upload_to='clients_data/', blank=True)
    file5 = models.ImageField(upload_to='clients_data/', blank=True)

    def __str__(self):
        return '%s %s' % (self.user, self.contractor_type)



from django.http import HttpResponseRedirect
from django.shortcuts import render

# Create your views here.
from django.urls import reverse
from registration.backends.default.views import RegistrationView

from stem_registration.forms import RegistrationForm


class RegistrationViewStem(RegistrationView):
    form_class = RegistrationForm

    # country = Country.objects.all()

    def get(self, request, *args, **kwargs):
        return render(request, self.template_name, {
            'form': self.form_class,
            # 'country': self.country
        })

    def post(self, request, *args, **kwargs):

        form_class = self.form_class(request.POST, request.FILES)

        client_presave = super(RegistrationViewStem, self)
        if form_class.is_valid():
            client = client_presave.register(form_class)

            # if request.POST.get('contractor_type') == 'PP':
            #     DocumentImages.objects.create(documents_files=form_class.cleaned_data['file1'],
            #                                   user_profile=client)
            #     DocumentImages.objects.create(documents_files=form_class.cleaned_data['file2'],
            #                                   user_profile=client)
            #     DocumentImages.objects.create(documents_files=form_class.cleaned_data['file3'],
            #                                   user_profile=client)
            #     DocumentImages.objects.create(documents_files=form_class.cleaned_data['file4'],
            #                                   user_profile=client)
            #
            # elif request.POST.get('contractor_type') == 'IE':
            #     DocumentImages.objects.create(documents_files=request.FILES.get('file1'), user_profile_id=client.id)
            #
            # phone = Phone.objects.create(content_object=client, source=client.username,
            #                              number=form_class.cleaned_data['number'],
            #                              created_by=client.username)
            # address = Address.objects.create(content_object=client, source=client.username,
            #                                  address=form_class.cleaned_data['address'],
            #                                  address_optional=form_class.cleaned_data['address_optional'],
            #                                  country_id=request.POST.get('country'),
            #                                  city=form_class.cleaned_data['city'],
            #                                  zip=form_class.cleaned_data['zip'],
            #                                  created_by=client.username)
            # email = Email.objects.create(content_object=client, source=client.username, created_by=client.username,
            #                              email=form_class.cleaned_data['email'])
            #
            # if not request.POST.get('same'):
            #     billing_address = Address.objects.create(content_object=client, source=client.username,
            #                                              address=form_class.cleaned_data['billing_address'],
            #                                              address_optional=form_class.cleaned_data[
            #                                                  'bill_address_optional'],
            #                                              country_id=request.POST.get('country'),
            #                                              city=form_class.cleaned_data['bill_city'],
            #                                              zip=form_class.cleaned_data['bill_zip'],
            #                                              created_by=client.username)
            # else:
            #     billing_address = address
            #
            # customer = Customer.objects.create(contractor_type=form_class.cleaned_data['contractor_type'],
            #                                    name=form_class.cleaned_data['name_legal'],
            #                                    name_legal=form_class.cleaned_data['name_legal'],
            #                                    tax_number=form_class.cleaned_data['tax_number'],
            #                                    accounting_number=form_class.cleaned_data['accounting_number'],
            #                                    prefix_code='',
            #                                    country_id=request.POST.get('country'),
            #                                    main_email_id=email.id,
            #                                    bill_address_id=billing_address.id,
            #                                    ship_address_id=address.id,
            #                                    created_by=client.username,
            #                                    source=client.username, )
            #
            # country = Country.objects.get(id=request.POST.get('country'))
            #
            # phone_customer = Phone.objects.create(content_object=customer, source=client.username,
            #                                       number=form_class.cleaned_data['number'],
            #                                       created_by=client.username)
            #
            # address_customer = Address.objects.create(content_object=customer, source=client.username,
            #                                           address=form_class.cleaned_data['address'],
            #                                           address_optional=form_class.cleaned_data['address_optional'],
            #                                           country_id=request.POST.get('country'),
            #                                           city=form_class.cleaned_data['city'],
            #                                           zip=form_class.cleaned_data['zip'],
            #                                           created_by=client.username)
            #
            # email_customer = Email.objects.create(content_object=customer, source=client.username,
            #                                       created_by=client.username,
            #                                       email=form_class.cleaned_data['email'])
            #
            # if not request.POST.get('same'):
            #     billing_address_customer = Address.objects.create(content_object=customer, source=client.username,
            #                                                       address=form_class.cleaned_data['billing_address'],
            #                                                       address_optional=form_class.cleaned_data[
            #                                                           'bill_address_optional'],
            #                                                       country_id=request.POST.get('country'),
            #                                                       city=form_class.cleaned_data['bill_city'],
            #                                                       zip=form_class.cleaned_data['bill_zip'],
            #                                                       created_by=client.username)
            # else:
            #     billing_address_customer = address_customer
            #
            # notification = Notification.objects.create(send_to_browser=True, send_to_telegram=phone_customer,
            #                                            send_to_viber=phone_customer,
            #                                            send_to_email=email, send_to_sms=phone_customer)

            # customer.main_phone = phone_customer
            # customer.main_customer = customer
            # customer.ship_address = address_customer
            # customer.bill_address = billing_address_customer
            # customer.main_email = email_customer
            # customer.save()
            #
            # client.ship_address = address
            # client.notification = notification
            # client.bill_address = billing_address
            # client.main_phone = phone
            # client.main_email = email
            # client.country = country
            # client.main_customer = customer
            client.save()
            return HttpResponseRedirect(reverse('registration_complete'))

        return render(request, self.template_name, {
            'form': form_class,
            # 'country': self.country
        })



# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2018-10-31 11:02
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stem_registration', '0002_auto_20181031_1101'),
    ]

    operations = [
        migrations.AddField(
            model_name='registrationdata',
            name='accounting_number',
            field=models.CharField(blank=True, default='', help_text='<details>для других страни или не используется или как-то иначе называется</details>', max_length=20, null=True, verbose_name='ЕГРПОУ'),
        ),
        migrations.AddField(
            model_name='registrationdata',
            name='name_legal',
            field=models.CharField(blank=True, default='', help_text='<details>Юридическое название компании, частного или индивидуального предпринимателя.<br>Для Частный лиц указывайте ФИО полностью<br>Это поле используется при формировании печатных форм документов</details>', max_length=255, verbose_name='Полное наименование'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2018-11-12 15:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('stem_registration', '0004_auto_20181107_1205'),
    ]

    operations = [
        migrations.AddField(
            model_name='registrationdata',
            name='file1',
            field=models.ImageField(blank=True, upload_to='clients_data/'),
        ),
        migrations.AddField(
            model_name='registrationdata',
            name='file2',
            field=models.ImageField(blank=True, upload_to='clients_data/'),
        ),
        migrations.AddField(
            model_name='registrationdata',
            name='file3',
            field=models.ImageField(blank=True, upload_to='clients_data/'),
        ),
        migrations.AddField(
            model_name='registrationdata',
            name='file4',
            field=models.ImageField(blank=True, upload_to='clients_data/'),
        ),
        migrations.AddField(
            model_name='registrationdata',
            name='file5',
            field=models.ImageField(blank=True, upload_to='clients_data/'),
        ),
        migrations.AlterField(
            model_name='registrationdata',
            name='bill_country',
            field=models.ForeignKey(blank=True, help_text='Страна происхождения контрагента', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='bill_countries', to='cities_light.Country', verbose_name='Страна'),
        ),
        migrations.AlterField(
            model_name='registrationdata',
            name='country',
            field=models.ForeignKey(blank=True, help_text='Страна происхождения контрагента', null=True, on_delete=django.db.models.deletion.SET_NULL, to='cities_light.Country', verbose_name='Страна'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2018-11-07 10:05
from __future__ import unicode_literals

from django.db import migrations

DATA = [
  {
    "id": 3,
    "name_ascii": "Andorra",
    "slug": "andorra",
    "geoname_id": 3041565,
    "alternate_names": "213;Principality of Andorra;Андорра",
    "code2": "AD",
    "code3": "AND",
    "continent": "EU",
    "tld": "ad",
    "phone": "376",
    "name": "Andorra"
  },
  {
    "id": 4,
    "name_ascii": "United Arab Emirates",
    "slug": "united-arab-emirates",
    "geoname_id": 290557,
    "alternate_names": "Объединенные Арабские Эмираты;Объединённые Арабские Эмираты",
    "code2": "AE",
    "code3": "ARE",
    "continent": "AS",
    "tld": "ae",
    "phone": "971",
    "name": "United Arab Emirates"
  },
  {
    "id": 5,
    "name_ascii": "Afghanistan",
    "slug": "afghanistan",
    "geoname_id": 1149361,
    "alternate_names": "Islamic Republic of Afghanistan;Афганистан",
    "code2": "AF",
    "code3": "AFG",
    "continent": "AS",
    "tld": "af",
    "phone": "93",
    "name": "Afghanistan"
  },
  {
    "id": 6,
    "name_ascii": "Antigua and Barbuda",
    "slug": "antigua-and-barbuda",
    "geoname_id": 3576396,
    "alternate_names": "Антигуа и Барбуда",
    "code2": "AG",
    "code3": "ATG",
    "continent": "NA",
    "tld": "ag",
    "phone": "1-268",
    "name": "Antigua and Barbuda"
  },
  {
    "id": 7,
    "name_ascii": "Anguilla",
    "slug": "anguilla",
    "geoname_id": 3573511,
    "alternate_names": "Ангилья",
    "code2": "AI",
    "code3": "AIA",
    "continent": "NA",
    "tld": "ai",
    "phone": "1-264",
    "name": "Anguilla"
  },
  {
    "id": 8,
    "name_ascii": "Albania",
    "slug": "albania",
    "geoname_id": 783754,
    "alternate_names": "Republic of Albania;Албания",
    "code2": "AL",
    "code3": "ALB",
    "continent": "EU",
    "tld": "al",
    "phone": "355",
    "name": "Albania"
  },
  {
    "id": 9,
    "name_ascii": "Armenia",
    "slug": "armenia",
    "geoname_id": 174982,
    "alternate_names": "Republic of Armenia;Армения",
    "code2": "AM",
    "code3": "ARM",
    "continent": "AS",
    "tld": "am",
    "phone": "374",
    "name": "Armenia"
  },
  {
    "id": 10,
    "name_ascii": "Angola",
    "slug": "angola",
    "geoname_id": 3351879,
    "alternate_names": "Republic of Angola;Ангола",
    "code2": "AO",
    "code3": "AGO",
    "continent": "AF",
    "tld": "ao",
    "phone": "244",
    "name": "Angola"
  },
  {
    "id": 11,
    "name_ascii": "Antarctica",
    "slug": "antarctica",
    "geoname_id": 6697173,
    "alternate_names": "Антарктида",
    "code2": "AQ",
    "code3": "ATA",
    "continent": "AN",
    "tld": "aq",
    "phone": "",
    "name": "Antarctica"
  },
  {
    "id": 12,
    "name_ascii": "Argentina",
    "slug": "argentina",
    "geoname_id": 3865483,
    "alternate_names": "Argentine Republic;Аргентина",
    "code2": "AR",
    "code3": "ARG",
    "continent": "SA",
    "tld": "ar",
    "phone": "54",
    "name": "Argentina"
  },
  {
    "id": 13,
    "name_ascii": "American Samoa",
    "slug": "american-samoa",
    "geoname_id": 5880801,
    "alternate_names": "Американское Самоа",
    "code2": "AS",
    "code3": "ASM",
    "continent": "OC",
    "tld": "as",
    "phone": "1-684",
    "name": "American Samoa"
  },
  {
    "id": 14,
    "name_ascii": "Austria",
    "slug": "austria",
    "geoname_id": 2782113,
    "alternate_names": "Republic of Austria;Австрия",
    "code2": "AT",
    "code3": "AUT",
    "continent": "EU",
    "tld": "at",
    "phone": "43",
    "name": "Austria"
  },
  {
    "id": 15,
    "name_ascii": "Australia",
    "slug": "australia",
    "geoname_id": 2077456,
    "alternate_names": "Австралия",
    "code2": "AU",
    "code3": "AUS",
    "continent": "OC",
    "tld": "au",
    "phone": "61",
    "name": "Australia"
  },
  {
    "id": 16,
    "name_ascii": "Aruba",
    "slug": "aruba",
    "geoname_id": 3577279,
    "alternate_names": "Аруба",
    "code2": "AW",
    "code3": "ABW",
    "continent": "NA",
    "tld": "aw",
    "phone": "297",
    "name": "Aruba"
  },
  {
    "id": 17,
    "name_ascii": "Aland Islands",
    "slug": "aland-islands",
    "geoname_id": 661882,
    "alternate_names": "Province of Åland;Åland Islands;Аландские острова",
    "code2": "AX",
    "code3": "ALA",
    "continent": "EU",
    "tld": "ax",
    "phone": "358-18",
    "name": "Aland Islands"
  },
  {
    "id": 18,
    "name_ascii": "Azerbaijan",
    "slug": "azerbaijan",
    "geoname_id": 587116,
    "alternate_names": "Republic of Azerbaijan;Азербайджан",
    "code2": "AZ",
    "code3": "AZE",
    "continent": "AS",
    "tld": "az",
    "phone": "994",
    "name": "Azerbaijan"
  },
  {
    "id": 19,
    "name_ascii": "Bosnia and Herzegovina",
    "slug": "bosnia-and-herzegovina",
    "geoname_id": 3277605,
    "alternate_names": "Босния;Босния и Герцеговина",
    "code2": "BA",
    "code3": "BIH",
    "continent": "EU",
    "tld": "ba",
    "phone": "387",
    "name": "Bosnia and Herzegovina"
  },
  {
    "id": 20,
    "name_ascii": "Barbados",
    "slug": "barbados",
    "geoname_id": 3374084,
    "alternate_names": "Барбадос",
    "code2": "BB",
    "code3": "BRB",
    "continent": "NA",
    "tld": "bb",
    "phone": "1-246",
    "name": "Barbados"
  },
  {
    "id": 21,
    "name_ascii": "Bangladesh",
    "slug": "bangladesh",
    "geoname_id": 1210997,
    "alternate_names": "Бангладеш",
    "code2": "BD",
    "code3": "BGD",
    "continent": "AS",
    "tld": "bd",
    "phone": "880",
    "name": "Bangladesh"
  },
  {
    "id": 22,
    "name_ascii": "Belgium",
    "slug": "belgium",
    "geoname_id": 2802361,
    "alternate_names": "Kingdom of Belgium;Бельгия",
    "code2": "BE",
    "code3": "BEL",
    "continent": "EU",
    "tld": "be",
    "phone": "32",
    "name": "Belgium"
  },
  {
    "id": 23,
    "name_ascii": "Burkina Faso",
    "slug": "burkina-faso",
    "geoname_id": 2361809,
    "alternate_names": "Буркина Фасо;Буркина-Фасо",
    "code2": "BF",
    "code3": "BFA",
    "continent": "AF",
    "tld": "bf",
    "phone": "226",
    "name": "Burkina Faso"
  },
  {
    "id": 24,
    "name_ascii": "Bulgaria",
    "slug": "bulgaria",
    "geoname_id": 732800,
    "alternate_names": "Republic of Bulgaria;Болгария",
    "code2": "BG",
    "code3": "BGR",
    "continent": "EU",
    "tld": "bg",
    "phone": "359",
    "name": "Bulgaria"
  },
  {
    "id": 25,
    "name_ascii": "Bahrain",
    "slug": "bahrain",
    "geoname_id": 290291,
    "alternate_names": "Kingdom of Bahrain;Бахрейн",
    "code2": "BH",
    "code3": "BHR",
    "continent": "AS",
    "tld": "bh",
    "phone": "973",
    "name": "Bahrain"
  },
  {
    "id": 26,
    "name_ascii": "Burundi",
    "slug": "burundi",
    "geoname_id": 433561,
    "alternate_names": "Republic of Burundi;Бурунди",
    "code2": "BI",
    "code3": "BDI",
    "continent": "AF",
    "tld": "bi",
    "phone": "257",
    "name": "Burundi"
  },
  {
    "id": 27,
    "name_ascii": "Benin",
    "slug": "benin",
    "geoname_id": 2395170,
    "alternate_names": "Republic of Benin;Бенин",
    "code2": "BJ",
    "code3": "BEN",
    "continent": "AF",
    "tld": "bj",
    "phone": "229",
    "name": "Benin"
  },
  {
    "id": 28,
    "name_ascii": "Saint Barthelemy",
    "slug": "saint-barthelemy",
    "geoname_id": 3578476,
    "alternate_names": "Saint Barthélemy;Territorial collectivity of Saint-Barthélemy;Остров Святого Бартоломея;Сен-Бартелеми;Сен-Бартельми",
    "code2": "BL",
    "code3": "BLM",
    "continent": "NA",
    "tld": "gp",
    "phone": "590",
    "name": "Saint Barthelemy"
  },
  {
    "id": 29,
    "name_ascii": "Bermuda",
    "slug": "bermuda",
    "geoname_id": 3573345,
    "alternate_names": "Бермудские Острова;Бермудские о-ва",
    "code2": "BM",
    "code3": "BMU",
    "continent": "NA",
    "tld": "bm",
    "phone": "1-441",
    "name": "Bermuda"
  },
  {
    "id": 30,
    "name_ascii": "Brunei",
    "slug": "brunei",
    "geoname_id": 1820814,
    "alternate_names": "Brunei Darussalam;Бруней;Бруней Даруссалам",
    "code2": "BN",
    "code3": "BRN",
    "continent": "AS",
    "tld": "bn",
    "phone": "673",
    "name": "Brunei"
  },
  {
    "id": 31,
    "name_ascii": "Bolivia",
    "slug": "bolivia",
    "geoname_id": 3923057,
    "alternate_names": "Bolivia (Plurinational State of);Bolivia, Plurinational State Of;Plurinational State of Bolivia;Republic of Bolivia;Боливия",
    "code2": "BO",
    "code3": "BOL",
    "continent": "SA",
    "tld": "bo",
    "phone": "591",
    "name": "Bolivia"
  },
  {
    "id": 32,
    "name_ascii": "Bonaire, Saint Eustatius and Saba",
    "slug": "bonaire-saint-eustatius-and-saba",
    "geoname_id": 7626844,
    "alternate_names": "Bonaire, Saint Eustatius, and Saba;Bonaire, Sint Eustatius and Saba;Caribbean Netherlands;Бонайре, Синт-Эстатиус и Саба",
    "code2": "BQ",
    "code3": "BES",
    "continent": "NA",
    "tld": "bq",
    "phone": "599",
    "name": "Bonaire, Saint Eustatius and Saba"
  },
  {
    "id": 33,
    "name_ascii": "Brazil",
    "slug": "brazil",
    "geoname_id": 3469034,
    "alternate_names": "Federative Republic of Brazil;Бразилия",
    "code2": "BR",
    "code3": "BRA",
    "continent": "SA",
    "tld": "br",
    "phone": "55",
    "name": "Brazil"
  },
  {
    "id": 34,
    "name_ascii": "Bahamas",
    "slug": "bahamas",
    "geoname_id": 3572887,
    "alternate_names": "The Bahamas;Багамские острова;Багамы",
    "code2": "BS",
    "code3": "BHS",
    "continent": "NA",
    "tld": "bs",
    "phone": "1-242",
    "name": "Bahamas"
  },
  {
    "id": 35,
    "name_ascii": "Bhutan",
    "slug": "bhutan",
    "geoname_id": 1252634,
    "alternate_names": "Бутан",
    "code2": "BT",
    "code3": "BTN",
    "continent": "AS",
    "tld": "bt",
    "phone": "975",
    "name": "Bhutan"
  },
  {
    "id": 36,
    "name_ascii": "Bouvet Island",
    "slug": "bouvet-island",
    "geoname_id": 3371123,
    "alternate_names": "Остров Буве",
    "code2": "BV",
    "code3": "BVT",
    "continent": "AN",
    "tld": "bv",
    "phone": "",
    "name": "Bouvet Island"
  },
  {
    "id": 37,
    "name_ascii": "Botswana",
    "slug": "botswana",
    "geoname_id": 933860,
    "alternate_names": "Ботсвана",
    "code2": "BW",
    "code3": "BWA",
    "continent": "AF",
    "tld": "bw",
    "phone": "267",
    "name": "Botswana"
  },
  {
    "id": 38,
    "name_ascii": "Belarus",
    "slug": "belarus",
    "geoname_id": 630336,
    "alternate_names": "Belarus’;Republic of Belarus;Respublika Belarus’;Беларусь;Белоруссия;Республика Беларусь",
    "code2": "BY",
    "code3": "BLR",
    "continent": "EU",
    "tld": "by",
    "phone": "375",
    "name": "Belarus"
  },
  {
    "id": 39,
    "name_ascii": "Belize",
    "slug": "belize",
    "geoname_id": 3582678,
    "alternate_names": "Белиз",
    "code2": "BZ",
    "code3": "BLZ",
    "continent": "NA",
    "tld": "bz",
    "phone": "501",
    "name": "Belize"
  },
  {
    "id": 40,
    "name_ascii": "Canada",
    "slug": "canada",
    "geoname_id": 6251999,
    "alternate_names": "Канада",
    "code2": "CA",
    "code3": "CAN",
    "continent": "NA",
    "tld": "ca",
    "phone": "1",
    "name": "Canada"
  },
  {
    "id": 41,
    "name_ascii": "Cocos Islands",
    "slug": "cocos-islands",
    "geoname_id": 1547376,
    "alternate_names": "Cocos [Keeling] Islands;Кокосовые о-ва",
    "code2": "CC",
    "code3": "CCK",
    "continent": "AS",
    "tld": "cc",
    "phone": "61",
    "name": "Cocos Islands"
  },
  {
    "id": 42,
    "name_ascii": "Democratic Republic of the Congo",
    "slug": "democratic-republic-of-the-congo",
    "geoname_id": 203312,
    "alternate_names": "Congo [DRC];Congo, The Democratic Republic Of;Congo-Kinshasa;Democratic Republic of Congo;Демократическая Республика Конго;Заир;Конго, Демократическая Республика",
    "code2": "CD",
    "code3": "COD",
    "continent": "AF",
    "tld": "cd",
    "phone": "243",
    "name": "Democratic Republic of the Congo"
  },
  {
    "id": 43,
    "name_ascii": "Central African Republic",
    "slug": "central-african-republic",
    "geoname_id": 239880,
    "alternate_names": "ЦАР;Центральноафриканская Республика",
    "code2": "CF",
    "code3": "CAF",
    "continent": "AF",
    "tld": "cf",
    "phone": "236",
    "name": "Central African Republic"
  },
  {
    "id": 44,
    "name_ascii": "Republic of the Congo",
    "slug": "republic-of-the-congo",
    "geoname_id": 2260494,
    "alternate_names": "Congo (Brazzaville);Congo-Brazzaville;Конго;Республика Конго",
    "code2": "CG",
    "code3": "COG",
    "continent": "AF",
    "tld": "cg",
    "phone": "242",
    "name": "Republic of the Congo"
  },
  {
    "id": 45,
    "name_ascii": "Switzerland",
    "slug": "switzerland",
    "geoname_id": 2658434,
    "alternate_names": "Швейцария",
    "code2": "CH",
    "code3": "CHE",
    "continent": "EU",
    "tld": "ch",
    "phone": "41",
    "name": "Switzerland"
  },
  {
    "id": 46,
    "name_ascii": "Ivory Coast",
    "slug": "ivory-coast",
    "geoname_id": 2287781,
    "alternate_names": "Côte d'Ivoire;Côte d’Ivoire;Republic of Côte d’Ivoire;Кот д’Ивуар;Кот-д'Ивуар;Кот-д’Ивуар",
    "code2": "CI",
    "code3": "CIV",
    "continent": "AF",
    "tld": "ci",
    "phone": "225",
    "name": "Ivory Coast"
  },
  {
    "id": 47,
    "name_ascii": "Cook Islands",
    "slug": "cook-islands",
    "geoname_id": 1899402,
    "alternate_names": "Острова Кука",
    "code2": "CK",
    "code3": "COK",
    "continent": "OC",
    "tld": "ck",
    "phone": "682",
    "name": "Cook Islands"
  },
  {
    "id": 48,
    "name_ascii": "Chile",
    "slug": "chile",
    "geoname_id": 3895114,
    "alternate_names": "Republic of Chile;Чили",
    "code2": "CL",
    "code3": "CHL",
    "continent": "SA",
    "tld": "cl",
    "phone": "56",
    "name": "Chile"
  },
  {
    "id": 49,
    "name_ascii": "Cameroon",
    "slug": "cameroon",
    "geoname_id": 2233387,
    "alternate_names": "Republic of Cameroon;Камерун",
    "code2": "CM",
    "code3": "CMR",
    "continent": "AF",
    "tld": "cm",
    "phone": "237",
    "name": "Cameroon"
  },
  {
    "id": 50,
    "name_ascii": "China",
    "slug": "china",
    "geoname_id": 1814991,
    "alternate_names": "People's Republic of China;People’s Republic of China",
    "code2": "CN",
    "code3": "CHN",
    "continent": "AS",
    "tld": "cn",
    "phone": "86",
    "name": "China"
  },
  {
    "id": 51,
    "name_ascii": "Colombia",
    "slug": "colombia",
    "geoname_id": 3686110,
    "alternate_names": "Republic of Colombia;Колумбия",
    "code2": "CO",
    "code3": "COL",
    "continent": "SA",
    "tld": "co",
    "phone": "57",
    "name": "Colombia"
  },
  {
    "id": 52,
    "name_ascii": "Costa Rica",
    "slug": "costa-rica",
    "geoname_id": 3624060,
    "alternate_names": "Republic of Costa Rica;Коста-Рика",
    "code2": "CR",
    "code3": "CRI",
    "continent": "NA",
    "tld": "cr",
    "phone": "506",
    "name": "Costa Rica"
  },
  {
    "id": 53,
    "name_ascii": "Cuba",
    "slug": "cuba",
    "geoname_id": 3562981,
    "alternate_names": "Republic of Cuba;Куба",
    "code2": "CU",
    "code3": "CUB",
    "continent": "NA",
    "tld": "cu",
    "phone": "53",
    "name": "Cuba"
  },
  {
    "id": 54,
    "name_ascii": "Cape Verde",
    "slug": "cape-verde",
    "geoname_id": 3374766,
    "alternate_names": "Republic of Cabo Verde;Republic of Cape Verde;Острова Зеленого Мыса",
    "code2": "CV",
    "code3": "CPV",
    "continent": "AF",
    "tld": "cv",
    "phone": "238",
    "name": "Cape Verde"
  },
  {
    "id": 55,
    "name_ascii": "Curacao",
    "slug": "curacao",
    "geoname_id": 7626836,
    "alternate_names": "Country of Curaçao",
    "code2": "CW",
    "code3": "CUW",
    "continent": "NA",
    "tld": "cw",
    "phone": "599",
    "name": "Curacao"
  },
  {
    "id": 56,
    "name_ascii": "Christmas Island",
    "slug": "christmas-island",
    "geoname_id": 2078138,
    "alternate_names": "Остров Рождества",
    "code2": "CX",
    "code3": "CXR",
    "continent": "OC",
    "tld": "cx",
    "phone": "61",
    "name": "Christmas Island"
  },
  {
    "id": 57,
    "name_ascii": "Cyprus",
    "slug": "cyprus",
    "geoname_id": 146669,
    "alternate_names": "Кипр",
    "code2": "CY",
    "code3": "CYP",
    "continent": "EU",
    "tld": "cy",
    "phone": "357",
    "name": "Cyprus"
  },
  {
    "id": 58,
    "name_ascii": "Czechia",
    "slug": "czechia",
    "geoname_id": 3077311,
    "alternate_names": "Czech Republic;Чехия;Чешская Республика",
    "code2": "CZ",
    "code3": "CZE",
    "continent": "EU",
    "tld": "cz",
    "phone": "420",
    "name": "Czechia"
  },
  {
    "id": 59,
    "name_ascii": "Germany",
    "slug": "germany",
    "geoname_id": 2921044,
    "alternate_names": "Federal Republic of Germany;Германия",
    "code2": "DE",
    "code3": "DEU",
    "continent": "EU",
    "tld": "de",
    "phone": "49",
    "name": "Germany"
  },
  {
    "id": 60,
    "name_ascii": "Djibouti",
    "slug": "djibouti",
    "geoname_id": 223816,
    "alternate_names": "Republic of Djibouti;Джибути",
    "code2": "DJ",
    "code3": "DJI",
    "continent": "AF",
    "tld": "dj",
    "phone": "253",
    "name": "Djibouti"
  },
  {
    "id": 61,
    "name_ascii": "Denmark",
    "slug": "denmark",
    "geoname_id": 2623032,
    "alternate_names": "Kingdom of Denmark;Дания",
    "code2": "DK",
    "code3": "DNK",
    "continent": "EU",
    "tld": "dk",
    "phone": "45",
    "name": "Denmark"
  },
  {
    "id": 62,
    "name_ascii": "Dominica",
    "slug": "dominica",
    "geoname_id": 3575830,
    "alternate_names": "Commonwealth of Dominica;Доминика;Остров Доминика",
    "code2": "DM",
    "code3": "DMA",
    "continent": "NA",
    "tld": "dm",
    "phone": "1-767",
    "name": "Dominica"
  },
  {
    "id": 63,
    "name_ascii": "Dominican Republic",
    "slug": "dominican-republic",
    "geoname_id": 3508796,
    "alternate_names": "Доминиканская Республика",
    "code2": "DO",
    "code3": "DOM",
    "continent": "NA",
    "tld": "do",
    "phone": "1-809 and 1-829",
    "name": "Dominican Republic"
  },
  {
    "id": 64,
    "name_ascii": "Algeria",
    "slug": "algeria",
    "geoname_id": 2589581,
    "alternate_names": "People’s Democratic Republic of Algeria;Алжир",
    "code2": "DZ",
    "code3": "DZA",
    "continent": "AF",
    "tld": "dz",
    "phone": "213",
    "name": "Algeria"
  },
  {
    "id": 65,
    "name_ascii": "Ecuador",
    "slug": "ecuador",
    "geoname_id": 3658394,
    "alternate_names": "Republic of Ecuador;Эквадор",
    "code2": "EC",
    "code3": "ECU",
    "continent": "SA",
    "tld": "ec",
    "phone": "593",
    "name": "Ecuador"
  },
  {
    "id": 66,
    "name_ascii": "Estonia",
    "slug": "estonia",
    "geoname_id": 453733,
    "alternate_names": "Republic of Estonia;Эстония",
    "code2": "EE",
    "code3": "EST",
    "continent": "EU",
    "tld": "ee",
    "phone": "372",
    "name": "Estonia"
  },
  {
    "id": 67,
    "name_ascii": "Egypt",
    "slug": "egypt",
    "geoname_id": 357994,
    "alternate_names": "Arab Republic of Egypt;Египет",
    "code2": "EG",
    "code3": "EGY",
    "continent": "AF",
    "tld": "eg",
    "phone": "20",
    "name": "Egypt"
  },
  {
    "id": 68,
    "name_ascii": "Western Sahara",
    "slug": "western-sahara",
    "geoname_id": 2461445,
    "alternate_names": "Западная Сахара",
    "code2": "EH",
    "code3": "ESH",
    "continent": "AF",
    "tld": "eh",
    "phone": "212",
    "name": "Western Sahara"
  },
  {
    "id": 69,
    "name_ascii": "Eritrea",
    "slug": "eritrea",
    "geoname_id": 338010,
    "alternate_names": "State of Eritrea;Эритрея",
    "code2": "ER",
    "code3": "ERI",
    "continent": "AF",
    "tld": "er",
    "phone": "291",
    "name": "Eritrea"
  },
  {
    "id": 70,
    "name_ascii": "Spain",
    "slug": "spain",
    "geoname_id": 2510769,
    "alternate_names": "Kingdom of Spain;Spanish State;Испания",
    "code2": "ES",
    "code3": "ESP",
    "continent": "EU",
    "tld": "es",
    "phone": "34",
    "name": "Spain"
  },
  {
    "id": 71,
    "name_ascii": "Ethiopia",
    "slug": "ethiopia",
    "geoname_id": 337996,
    "alternate_names": "Federal Democratic Republic of Ethiopia;Эфиопия",
    "code2": "ET",
    "code3": "ETH",
    "continent": "AF",
    "tld": "et",
    "phone": "251",
    "name": "Ethiopia"
  },
  {
    "id": 72,
    "name_ascii": "Finland",
    "slug": "finland",
    "geoname_id": 660013,
    "alternate_names": "Republic of Finland;Финляндия",
    "code2": "FI",
    "code3": "FIN",
    "continent": "EU",
    "tld": "fi",
    "phone": "358",
    "name": "Finland"
  },
  {
    "id": 73,
    "name_ascii": "Fiji",
    "slug": "fiji",
    "geoname_id": 2205218,
    "alternate_names": "Фиджи",
    "code2": "FJ",
    "code3": "FJI",
    "continent": "OC",
    "tld": "fj",
    "phone": "679",
    "name": "Fiji"
  },
  {
    "id": 74,
    "name_ascii": "Falkland Islands",
    "slug": "falkland-islands",
    "geoname_id": 3474414,
    "alternate_names": "Colony of the Falkland Islands;Falkland Islands (Malvinas);Фолклендские о-ва",
    "code2": "FK",
    "code3": "FLK",
    "continent": "SA",
    "tld": "fk",
    "phone": "500",
    "name": "Falkland Islands"
  },
  {
    "id": 75,
    "name_ascii": "Micronesia",
    "slug": "micronesia",
    "geoname_id": 2081918,
    "alternate_names": "Federated States of Micronesia;Micronesia, Federated States Of;Микронезия;Федеративные Штаты Микронезии",
    "code2": "FM",
    "code3": "FSM",
    "continent": "OC",
    "tld": "fm",
    "phone": "691",
    "name": "Micronesia"
  },
  {
    "id": 76,
    "name_ascii": "Faroe Islands",
    "slug": "faroe-islands",
    "geoname_id": 2622320,
    "alternate_names": "Фарерские о-ва;Фарерские острова",
    "code2": "FO",
    "code3": "FRO",
    "continent": "EU",
    "tld": "fo",
    "phone": "298",
    "name": "Faroe Islands"
  },
  {
    "id": 77,
    "name_ascii": "France",
    "slug": "france",
    "geoname_id": 3017382,
    "alternate_names": "Франция",
    "code2": "FR",
    "code3": "FRA",
    "continent": "EU",
    "tld": "fr",
    "phone": "33",
    "name": "France"
  },
  {
    "id": 78,
    "name_ascii": "Gabon",
    "slug": "gabon",
    "geoname_id": 2400553,
    "alternate_names": "Gabonese Republic;Габон",
    "code2": "GA",
    "code3": "GAB",
    "continent": "AF",
    "tld": "ga",
    "phone": "241",
    "name": "Gabon"
  },
  {
    "id": 79,
    "name_ascii": "United Kingdom",
    "slug": "united-kingdom",
    "geoname_id": 2635167,
    "alternate_names": "Britain;U.K.;UK;United Kingdom of Great Britain and Northern Ireland;Великобритания;Соединенное Королевство",
    "code2": "GB",
    "code3": "GBR",
    "continent": "EU",
    "tld": "uk",
    "phone": "44",
    "name": "United Kingdom"
  },
  {
    "id": 80,
    "name_ascii": "Grenada",
    "slug": "grenada",
    "geoname_id": 3580239,
    "alternate_names": "Гренада",
    "code2": "GD",
    "code3": "GRD",
    "continent": "NA",
    "tld": "gd",
    "phone": "1-473",
    "name": "Grenada"
  },
  {
    "id": 81,
    "name_ascii": "Georgia",
    "slug": "georgia",
    "geoname_id": 614540,
    "alternate_names": "Грузия",
    "code2": "GE",
    "code3": "GEO",
    "continent": "AS",
    "tld": "ge",
    "phone": "995",
    "name": "Georgia"
  },
  {
    "id": 82,
    "name_ascii": "French Guiana",
    "slug": "french-guiana",
    "geoname_id": 3381670,
    "alternate_names": "Французская Гвиана",
    "code2": "GF",
    "code3": "GUF",
    "continent": "SA",
    "tld": "gf",
    "phone": "594",
    "name": "French Guiana"
  },
  {
    "id": 83,
    "name_ascii": "Guernsey",
    "slug": "guernsey",
    "geoname_id": 3042362,
    "alternate_names": "Гернси",
    "code2": "GG",
    "code3": "GGY",
    "continent": "EU",
    "tld": "gg",
    "phone": "44-1481",
    "name": "Guernsey"
  },
  {
    "id": 84,
    "name_ascii": "Ghana",
    "slug": "ghana",
    "geoname_id": 2300660,
    "alternate_names": "Гана",
    "code2": "GH",
    "code3": "GHA",
    "continent": "AF",
    "tld": "gh",
    "phone": "233",
    "name": "Ghana"
  },
  {
    "id": 85,
    "name_ascii": "Gibraltar",
    "slug": "gibraltar",
    "geoname_id": 2411586,
    "alternate_names": "Гибралтар",
    "code2": "GI",
    "code3": "GIB",
    "continent": "EU",
    "tld": "gi",
    "phone": "350",
    "name": "Gibraltar"
  },
  {
    "id": 86,
    "name_ascii": "Greenland",
    "slug": "greenland",
    "geoname_id": 3425505,
    "alternate_names": "Гренландия",
    "code2": "GL",
    "code3": "GRL",
    "continent": "NA",
    "tld": "gl",
    "phone": "299",
    "name": "Greenland"
  },
  {
    "id": 87,
    "name_ascii": "Gambia",
    "slug": "gambia",
    "geoname_id": 2413451,
    "alternate_names": "Islamic Republic of The Gambia;The Gambia;Гамбия",
    "code2": "GM",
    "code3": "GMB",
    "continent": "AF",
    "tld": "gm",
    "phone": "220",
    "name": "Gambia"
  },
  {
    "id": 88,
    "name_ascii": "Guinea",
    "slug": "guinea",
    "geoname_id": 2420477,
    "alternate_names": "Republic of Guinea;Гвинея",
    "code2": "GN",
    "code3": "GIN",
    "continent": "AF",
    "tld": "gn",
    "phone": "224",
    "name": "Guinea"
  },
  {
    "id": 89,
    "name_ascii": "Guadeloupe",
    "slug": "guadeloupe",
    "geoname_id": 3579143,
    "alternate_names": "Гваделупа",
    "code2": "GP",
    "code3": "GLP",
    "continent": "NA",
    "tld": "gp",
    "phone": "590",
    "name": "Guadeloupe"
  },
  {
    "id": 90,
    "name_ascii": "Equatorial Guinea",
    "slug": "equatorial-guinea",
    "geoname_id": 2309096,
    "alternate_names": "Republic of Equatorial Guinea;Spanish Guinea;Экваториальная Гвинея",
    "code2": "GQ",
    "code3": "GNQ",
    "continent": "AF",
    "tld": "gq",
    "phone": "240",
    "name": "Equatorial Guinea"
  },
  {
    "id": 91,
    "name_ascii": "Greece",
    "slug": "greece",
    "geoname_id": 390903,
    "alternate_names": "Hellenic Republic;Греция",
    "code2": "GR",
    "code3": "GRC",
    "continent": "EU",
    "tld": "gr",
    "phone": "30",
    "name": "Greece"
  },
  {
    "id": 92,
    "name_ascii": "South Georgia and the South Sandwich Islands",
    "slug": "south-georgia-and-the-south-sandwich-islands",
    "geoname_id": 3474415,
    "alternate_names": "Южная Джорджия и Южные Сандвичевы Острова",
    "code2": "GS",
    "code3": "SGS",
    "continent": "AN",
    "tld": "gs",
    "phone": "",
    "name": "South Georgia and the South Sandwich Islands"
  },
  {
    "id": 93,
    "name_ascii": "Guatemala",
    "slug": "guatemala",
    "geoname_id": 3595528,
    "alternate_names": "Republic of Guatemala;Гватемала",
    "code2": "GT",
    "code3": "GTM",
    "continent": "NA",
    "tld": "gt",
    "phone": "502",
    "name": "Guatemala"
  },
  {
    "id": 94,
    "name_ascii": "Guam",
    "slug": "guam",
    "geoname_id": 4043988,
    "alternate_names": "Гуам",
    "code2": "GU",
    "code3": "GUM",
    "continent": "OC",
    "tld": "gu",
    "phone": "1-671",
    "name": "Guam"
  },
  {
    "id": 95,
    "name_ascii": "Guinea-Bissau",
    "slug": "guinea-bissau",
    "geoname_id": 2372248,
    "alternate_names": "Republic of Guinea-Bissau;Гвинея-Бисау;Гвинея-Биссау",
    "code2": "GW",
    "code3": "GNB",
    "continent": "AF",
    "tld": "gw",
    "phone": "245",
    "name": "Guinea-Bissau"
  },
  {
    "id": 96,
    "name_ascii": "Guyana",
    "slug": "guyana",
    "geoname_id": 3378535,
    "alternate_names": "Гайана",
    "code2": "GY",
    "code3": "GUY",
    "continent": "SA",
    "tld": "gy",
    "phone": "592",
    "name": "Guyana"
  },
  {
    "id": 97,
    "name_ascii": "Hong Kong",
    "slug": "hong-kong",
    "geoname_id": 1819730,
    "alternate_names": "Hong Kong Special Administrative Region;Гонконг",
    "code2": "HK",
    "code3": "HKG",
    "continent": "AS",
    "tld": "hk",
    "phone": "852",
    "name": "Hong Kong"
  },
  {
    "id": 98,
    "name_ascii": "Heard Island and McDonald Islands",
    "slug": "heard-island-and-mcdonald-islands",
    "geoname_id": 1547314,
    "alternate_names": "Острова Херд и Макдональд",
    "code2": "HM",
    "code3": "HMD",
    "continent": "AN",
    "tld": "hm",
    "phone": "",
    "name": "Heard Island and McDonald Islands"
  },
  {
    "id": 99,
    "name_ascii": "Honduras",
    "slug": "honduras",
    "geoname_id": 3608932,
    "alternate_names": "Republic of Honduras;Гондурас",
    "code2": "HN",
    "code3": "HND",
    "continent": "NA",
    "tld": "hn",
    "phone": "504",
    "name": "Honduras"
  },
  {
    "id": 100,
    "name_ascii": "Croatia",
    "slug": "croatia",
    "geoname_id": 3202326,
    "alternate_names": "Republic of Croatia;Хорватия",
    "code2": "HR",
    "code3": "HRV",
    "continent": "EU",
    "tld": "hr",
    "phone": "385",
    "name": "Croatia"
  },
  {
    "id": 101,
    "name_ascii": "Haiti",
    "slug": "haiti",
    "geoname_id": 3723988,
    "alternate_names": "Republic of Haiti;Гаити",
    "code2": "HT",
    "code3": "HTI",
    "continent": "NA",
    "tld": "ht",
    "phone": "509",
    "name": "Haiti"
  },
  {
    "id": 102,
    "name_ascii": "Hungary",
    "slug": "hungary",
    "geoname_id": 719819,
    "alternate_names": "Венгрия",
    "code2": "HU",
    "code3": "HUN",
    "continent": "EU",
    "tld": "hu",
    "phone": "36",
    "name": "Hungary"
  },
  {
    "id": 103,
    "name_ascii": "Indonesia",
    "slug": "indonesia",
    "geoname_id": 1643084,
    "alternate_names": "Republic of Indonesia;Индонезия",
    "code2": "ID",
    "code3": "IDN",
    "continent": "AS",
    "tld": "id",
    "phone": "62",
    "name": "Indonesia"
  },
  {
    "id": 104,
    "name_ascii": "Ireland",
    "slug": "ireland",
    "geoname_id": 2963597,
    "alternate_names": "Republic of Ireland;Ирландия",
    "code2": "IE",
    "code3": "IRL",
    "continent": "EU",
    "tld": "ie",
    "phone": "353",
    "name": "Ireland"
  },
  {
    "id": 105,
    "name_ascii": "Israel",
    "slug": "israel",
    "geoname_id": 294640,
    "alternate_names": "State of Israel;Израиль",
    "code2": "IL",
    "code3": "ISR",
    "continent": "AS",
    "tld": "il",
    "phone": "972",
    "name": "Israel"
  },
  {
    "id": 106,
    "name_ascii": "Isle of Man",
    "slug": "isle-of-man",
    "geoname_id": 3042225,
    "alternate_names": "Мэн, о-в;Остров Мэн",
    "code2": "IM",
    "code3": "IMN",
    "continent": "EU",
    "tld": "im",
    "phone": "44-1624",
    "name": "Isle of Man"
  },
  {
    "id": 107,
    "name_ascii": "India",
    "slug": "india",
    "geoname_id": 1269750,
    "alternate_names": "Индия",
    "code2": "IN",
    "code3": "IND",
    "continent": "AS",
    "tld": "in",
    "phone": "91",
    "name": "India"
  },
  {
    "id": 108,
    "name_ascii": "British Indian Ocean Territory",
    "slug": "british-indian-ocean-territory",
    "geoname_id": 1282588,
    "alternate_names": "Британская Территория в Индийском Океане;Британская территория в Индийском океане",
    "code2": "IO",
    "code3": "IOT",
    "continent": "AS",
    "tld": "io",
    "phone": "246",
    "name": "British Indian Ocean Territory"
  },
  {
    "id": 109,
    "name_ascii": "Iraq",
    "slug": "iraq",
    "geoname_id": 99237,
    "alternate_names": "Republic of Iraq;Ирак",
    "code2": "IQ",
    "code3": "IRQ",
    "continent": "AS",
    "tld": "iq",
    "phone": "964",
    "name": "Iraq"
  },
  {
    "id": 110,
    "name_ascii": "Iran",
    "slug": "iran",
    "geoname_id": 130758,
    "alternate_names": "Iran, Islamic Republic Of;Islamic Republic of Iran;Иран",
    "code2": "IR",
    "code3": "IRN",
    "continent": "AS",
    "tld": "ir",
    "phone": "98",
    "name": "Iran"
  },
  {
    "id": 111,
    "name_ascii": "Iceland",
    "slug": "iceland",
    "geoname_id": 2629691,
    "alternate_names": "Republic of Iceland;Исландия",
    "code2": "IS",
    "code3": "ISL",
    "continent": "EU",
    "tld": "is",
    "phone": "354",
    "name": "Iceland"
  },
  {
    "id": 112,
    "name_ascii": "Italy",
    "slug": "italy",
    "geoname_id": 3175395,
    "alternate_names": "Italian Republic;Republic of Italy;Италия",
    "code2": "IT",
    "code3": "ITA",
    "continent": "EU",
    "tld": "it",
    "phone": "39",
    "name": "Italy"
  },
  {
    "id": 113,
    "name_ascii": "Jersey",
    "slug": "jersey",
    "geoname_id": 3042142,
    "alternate_names": "Джерси",
    "code2": "JE",
    "code3": "JEY",
    "continent": "EU",
    "tld": "je",
    "phone": "44-1534",
    "name": "Jersey"
  },
  {
    "id": 114,
    "name_ascii": "Jamaica",
    "slug": "jamaica",
    "geoname_id": 3489940,
    "alternate_names": "Ямайка",
    "code2": "JM",
    "code3": "JAM",
    "continent": "NA",
    "tld": "jm",
    "phone": "1-876",
    "name": "Jamaica"
  },
  {
    "id": 115,
    "name_ascii": "Jordan",
    "slug": "jordan",
    "geoname_id": 248816,
    "alternate_names": "Hashemite Kingdom of Jordan;Иордания",
    "code2": "JO",
    "code3": "JOR",
    "continent": "AS",
    "tld": "jo",
    "phone": "962",
    "name": "Jordan"
  },
  {
    "id": 116,
    "name_ascii": "Japan",
    "slug": "japan",
    "geoname_id": 1861060,
    "alternate_names": "Япония",
    "code2": "JP",
    "code3": "JPN",
    "continent": "AS",
    "tld": "jp",
    "phone": "81",
    "name": "Japan"
  },
  {
    "id": 117,
    "name_ascii": "Kenya",
    "slug": "kenya",
    "geoname_id": 192950,
    "alternate_names": "Кения",
    "code2": "KE",
    "code3": "KEN",
    "continent": "AF",
    "tld": "ke",
    "phone": "254",
    "name": "Kenya"
  },
  {
    "id": 118,
    "name_ascii": "Kyrgyzstan",
    "slug": "kyrgyzstan",
    "geoname_id": 1527747,
    "alternate_names": "Kyrgyz Republic;Киргизия;Кыргызская Республика;Кыргызской Республики;Кыргызстан",
    "code2": "KG",
    "code3": "KGZ",
    "continent": "AS",
    "tld": "kg",
    "phone": "996",
    "name": "Kyrgyzstan"
  },
  {
    "id": 119,
    "name_ascii": "Cambodia",
    "slug": "cambodia",
    "geoname_id": 1831722,
    "alternate_names": "Democratic Cambodia;Democratic Kampuchea;Khmer Republic;Kingdom of Cambodia;Камбоджа",
    "code2": "KH",
    "code3": "KHM",
    "continent": "AS",
    "tld": "kh",
    "phone": "855",
    "name": "Cambodia"
  },
  {
    "id": 120,
    "name_ascii": "Kiribati",
    "slug": "kiribati",
    "geoname_id": 4030945,
    "alternate_names": "Кирибати",
    "code2": "KI",
    "code3": "KIR",
    "continent": "OC",
    "tld": "ki",
    "phone": "686",
    "name": "Kiribati"
  },
  {
    "id": 121,
    "name_ascii": "Comoros",
    "slug": "comoros",
    "geoname_id": 921929,
    "alternate_names": "Federal Islamic Republic of the Comoros;Republic of the Comoros;Union of the Comoros;Коморские о-ва;Коморы",
    "code2": "KM",
    "code3": "COM",
    "continent": "AF",
    "tld": "km",
    "phone": "269",
    "name": "Comoros"
  },
  {
    "id": 122,
    "name_ascii": "Saint Kitts and Nevis",
    "slug": "saint-kitts-and-nevis",
    "geoname_id": 3575174,
    "alternate_names": "St Kitts and Nevis;Сент-Китс и Невис;Сент-Киттс и Невис",
    "code2": "KN",
    "code3": "KNA",
    "continent": "NA",
    "tld": "kn",
    "phone": "1-869",
    "name": "Saint Kitts and Nevis"
  },
  {
    "id": 123,
    "name_ascii": "North Korea",
    "slug": "north-korea",
    "geoname_id": 1873107,
    "alternate_names": "Democratic People’s Republic of Korea;Korea, Democratic People’s Republic of;Корейская Народно-Демократическая Республика;Северная Корея",
    "code2": "KP",
    "code3": "PRK",
    "continent": "AS",
    "tld": "kp",
    "phone": "850",
    "name": "North Korea"
  },
  {
    "id": 124,
    "name_ascii": "South Korea",
    "slug": "south-korea",
    "geoname_id": 1835841,
    "alternate_names": "Korea, Republic of;Republic of Korea;Республика Корея;Южная Корея",
    "code2": "KR",
    "code3": "KOR",
    "continent": "AS",
    "tld": "kr",
    "phone": "82",
    "name": "South Korea"
  },
  {
    "id": 125,
    "name_ascii": "Kosovo",
    "slug": "kosovo",
    "geoname_id": 831053,
    "alternate_names": "Republic of Kosovo;Косово",
    "code2": "XK",
    "code3": "XKX",
    "continent": "EU",
    "tld": "",
    "phone": "",
    "name": "Kosovo"
  },
  {
    "id": 126,
    "name_ascii": "Kuwait",
    "slug": "kuwait",
    "geoname_id": 285570,
    "alternate_names": "State of Kuwait;Кувейт",
    "code2": "KW",
    "code3": "KWT",
    "continent": "AS",
    "tld": "kw",
    "phone": "965",
    "name": "Kuwait"
  },
  {
    "id": 127,
    "name_ascii": "Cayman Islands",
    "slug": "cayman-islands",
    "geoname_id": 3580718,
    "alternate_names": "Каймановы Острова;Острова Кайман",
    "code2": "KY",
    "code3": "CYM",
    "continent": "NA",
    "tld": "ky",
    "phone": "1-345",
    "name": "Cayman Islands"
  },
  {
    "id": 128,
    "name_ascii": "Kazakhstan",
    "slug": "kazakhstan",
    "geoname_id": 1522867,
    "alternate_names": "Republic of Kazakhstan;Республика Казахстан",
    "code2": "KZ",
    "code3": "KAZ",
    "continent": "AS",
    "tld": "kz",
    "phone": "7",
    "name": "Kazakhstan"
  },
  {
    "id": 129,
    "name_ascii": "Laos",
    "slug": "laos",
    "geoname_id": 1655842,
    "alternate_names": "Lao People’s Democratic Republic;Лаос",
    "code2": "LA",
    "code3": "LAO",
    "continent": "AS",
    "tld": "la",
    "phone": "856",
    "name": "Laos"
  },
  {
    "id": 130,
    "name_ascii": "Lebanon",
    "slug": "lebanon",
    "geoname_id": 272103,
    "alternate_names": "Republic of Lebanon;Ливан",
    "code2": "LB",
    "code3": "LBN",
    "continent": "AS",
    "tld": "lb",
    "phone": "961",
    "name": "Lebanon"
  },
  {
    "id": 131,
    "name_ascii": "Saint Lucia",
    "slug": "saint-lucia",
    "geoname_id": 3576468,
    "alternate_names": "St Lucia;Сент-Люсия",
    "code2": "LC",
    "code3": "LCA",
    "continent": "NA",
    "tld": "lc",
    "phone": "1-758",
    "name": "Saint Lucia"
  },
  {
    "id": 132,
    "name_ascii": "Liechtenstein",
    "slug": "liechtenstein",
    "geoname_id": 3042058,
    "alternate_names": "Principality of Liechtenstein;Лихтенштейн",
    "code2": "LI",
    "code3": "LIE",
    "continent": "EU",
    "tld": "li",
    "phone": "423",
    "name": "Liechtenstein"
  },
  {
    "id": 133,
    "name_ascii": "Sri Lanka",
    "slug": "sri-lanka",
    "geoname_id": 1227603,
    "alternate_names": "Шри-Ланка",
    "code2": "LK",
    "code3": "LKA",
    "continent": "AS",
    "tld": "lk",
    "phone": "94",
    "name": "Sri Lanka"
  },
  {
    "id": 134,
    "name_ascii": "Liberia",
    "slug": "liberia",
    "geoname_id": 2275384,
    "alternate_names": "Либерия",
    "code2": "LR",
    "code3": "LBR",
    "continent": "AF",
    "tld": "lr",
    "phone": "231",
    "name": "Liberia"
  },
  {
    "id": 135,
    "name_ascii": "Lesotho",
    "slug": "lesotho",
    "geoname_id": 932692,
    "alternate_names": "Лесото",
    "code2": "LS",
    "code3": "LSO",
    "continent": "AF",
    "tld": "ls",
    "phone": "266",
    "name": "Lesotho"
  },
  {
    "id": 136,
    "name_ascii": "Lithuania",
    "slug": "lithuania",
    "geoname_id": 597427,
    "alternate_names": "Republic of Lithuania;Литва",
    "code2": "LT",
    "code3": "LTU",
    "continent": "EU",
    "tld": "lt",
    "phone": "370",
    "name": "Lithuania"
  },
  {
    "id": 137,
    "name_ascii": "Luxembourg",
    "slug": "luxembourg",
    "geoname_id": 2960313,
    "alternate_names": "Grand Duchy of Luxembourg;Люксембург",
    "code2": "LU",
    "code3": "LUX",
    "continent": "EU",
    "tld": "lu",
    "phone": "352",
    "name": "Luxembourg"
  },
  {
    "id": 138,
    "name_ascii": "Latvia",
    "slug": "latvia",
    "geoname_id": 458258,
    "alternate_names": "Republic of Latvia;Латвия",
    "code2": "LV",
    "code3": "LVA",
    "continent": "EU",
    "tld": "lv",
    "phone": "371",
    "name": "Latvia"
  },
  {
    "id": 139,
    "name_ascii": "Libya",
    "slug": "libya",
    "geoname_id": 2215636,
    "alternate_names": "Ливия",
    "code2": "LY",
    "code3": "LBY",
    "continent": "AF",
    "tld": "ly",
    "phone": "218",
    "name": "Libya"
  },
  {
    "id": 140,
    "name_ascii": "Morocco",
    "slug": "morocco",
    "geoname_id": 2542007,
    "alternate_names": "Kingdom of Morocco;Марокко",
    "code2": "MA",
    "code3": "MAR",
    "continent": "AF",
    "tld": "ma",
    "phone": "212",
    "name": "Morocco"
  },
  {
    "id": 141,
    "name_ascii": "Monaco",
    "slug": "monaco",
    "geoname_id": 2993457,
    "alternate_names": "Монако",
    "code2": "MC",
    "code3": "MCO",
    "continent": "EU",
    "tld": "mc",
    "phone": "377",
    "name": "Monaco"
  },
  {
    "id": 142,
    "name_ascii": "Moldova",
    "slug": "moldova",
    "geoname_id": 617790,
    "alternate_names": "Moldova, Republic Of;Republic of Moldova;Молдавия;Молдова",
    "code2": "MD",
    "code3": "MDA",
    "continent": "EU",
    "tld": "md",
    "phone": "373",
    "name": "Moldova"
  },
  {
    "id": 143,
    "name_ascii": "Montenegro",
    "slug": "montenegro",
    "geoname_id": 3194884,
    "alternate_names": "Republic of Montenegro;Socialist Republic of Montenegro;Черногория",
    "code2": "ME",
    "code3": "MNE",
    "continent": "EU",
    "tld": "me",
    "phone": "382",
    "name": "Montenegro"
  },
  {
    "id": 144,
    "name_ascii": "Saint Martin",
    "slug": "saint-martin",
    "geoname_id": 3578421,
    "alternate_names": "Saint Martin (French Part);Saint-Martin Collectivity;St Martin;Остров Святого Мартина;Сен-Мартен",
    "code2": "MF",
    "code3": "MAF",
    "continent": "NA",
    "tld": "gp",
    "phone": "590",
    "name": "Saint Martin"
  },
  {
    "id": 145,
    "name_ascii": "Madagascar",
    "slug": "madagascar",
    "geoname_id": 1062947,
    "alternate_names": "Republic of Madagascar;Мадагаскар;Республика Мадагаскар",
    "code2": "MG",
    "code3": "MDG",
    "continent": "AF",
    "tld": "mg",
    "phone": "261",
    "name": "Madagascar"
  },
  {
    "id": 146,
    "name_ascii": "Marshall Islands",
    "slug": "marshall-islands",
    "geoname_id": 2080185,
    "alternate_names": "Маршалловы о-ва",
    "code2": "MH",
    "code3": "MHL",
    "continent": "OC",
    "tld": "mh",
    "phone": "692",
    "name": "Marshall Islands"
  },
  {
    "id": 147,
    "name_ascii": "Macedonia",
    "slug": "macedonia",
    "geoname_id": 718075,
    "alternate_names": "Republic of Macedonia;Македония;Республика Македония",
    "code2": "MK",
    "code3": "MKD",
    "continent": "EU",
    "tld": "mk",
    "phone": "389",
    "name": "Macedonia"
  },
  {
    "id": 148,
    "name_ascii": "Mali",
    "slug": "mali",
    "geoname_id": 2453866,
    "alternate_names": "Мали",
    "code2": "ML",
    "code3": "MLI",
    "continent": "AF",
    "tld": "ml",
    "phone": "223",
    "name": "Mali"
  },
  {
    "id": 149,
    "name_ascii": "Myanmar",
    "slug": "myanmar",
    "geoname_id": 1327865,
    "alternate_names": "Birma (Myanmar);Union of Burma;Мьянма",
    "code2": "MM",
    "code3": "MMR",
    "continent": "AS",
    "tld": "mm",
    "phone": "95",
    "name": "Myanmar"
  },
  {
    "id": 150,
    "name_ascii": "Mongolia",
    "slug": "mongolia",
    "geoname_id": 2029969,
    "alternate_names": "Mongol Peoples Republic;Mongolian People’s Republic;Монголия",
    "code2": "MN",
    "code3": "MNG",
    "continent": "AS",
    "tld": "mn",
    "phone": "976",
    "name": "Mongolia"
  },
  {
    "id": 151,
    "name_ascii": "Macao",
    "slug": "macao",
    "geoname_id": 1821275,
    "alternate_names": "Macau;Macau Special Administrative Region;Аомынь;Макао",
    "code2": "MO",
    "code3": "MAC",
    "continent": "AS",
    "tld": "mo",
    "phone": "853",
    "name": "Macao"
  },
  {
    "id": 152,
    "name_ascii": "Northern Mariana Islands",
    "slug": "northern-mariana-islands",
    "geoname_id": 4041468,
    "alternate_names": "Северные Марианские о-ва;Северные Марианские острова",
    "code2": "MP",
    "code3": "MNP",
    "continent": "OC",
    "tld": "mp",
    "phone": "1-670",
    "name": "Northern Mariana Islands"
  },
  {
    "id": 153,
    "name_ascii": "Martinique",
    "slug": "martinique",
    "geoname_id": 3570311,
    "alternate_names": "Мартиника",
    "code2": "MQ",
    "code3": "MTQ",
    "continent": "NA",
    "tld": "mq",
    "phone": "596",
    "name": "Martinique"
  },
  {
    "id": 154,
    "name_ascii": "Mauritania",
    "slug": "mauritania",
    "geoname_id": 2378080,
    "alternate_names": "Islamic Republic of Mauritania;Мавритания",
    "code2": "MR",
    "code3": "MRT",
    "continent": "AF",
    "tld": "mr",
    "phone": "222",
    "name": "Mauritania"
  },
  {
    "id": 155,
    "name_ascii": "Montserrat",
    "slug": "montserrat",
    "geoname_id": 3578097,
    "alternate_names": "Монсеррат;Монтсеррат",
    "code2": "MS",
    "code3": "MSR",
    "continent": "NA",
    "tld": "ms",
    "phone": "1-664",
    "name": "Montserrat"
  },
  {
    "id": 156,
    "name_ascii": "Malta",
    "slug": "malta",
    "geoname_id": 2562770,
    "alternate_names": "Malta Island;Republic of Malta;Мальта",
    "code2": "MT",
    "code3": "MLT",
    "continent": "EU",
    "tld": "mt",
    "phone": "356",
    "name": "Malta"
  },
  {
    "id": 157,
    "name_ascii": "Mauritius",
    "slug": "mauritius",
    "geoname_id": 934292,
    "alternate_names": "Republic of Mauritius;Маврикий",
    "code2": "MU",
    "code3": "MUS",
    "continent": "AF",
    "tld": "mu",
    "phone": "230",
    "name": "Mauritius"
  },
  {
    "id": 158,
    "name_ascii": "Maldives",
    "slug": "maldives",
    "geoname_id": 1282028,
    "alternate_names": "Republic of Maldives;Мальдивские о-ва",
    "code2": "MV",
    "code3": "MDV",
    "continent": "AS",
    "tld": "mv",
    "phone": "960",
    "name": "Maldives"
  },
  {
    "id": 159,
    "name_ascii": "Malawi",
    "slug": "malawi",
    "geoname_id": 927384,
    "alternate_names": "Малави",
    "code2": "MW",
    "code3": "MWI",
    "continent": "AF",
    "tld": "mw",
    "phone": "265",
    "name": "Malawi"
  },
  {
    "id": 160,
    "name_ascii": "Mexico",
    "slug": "mexico",
    "geoname_id": 3996063,
    "alternate_names": "Mexican Republic;United Mexican States;Мексика",
    "code2": "MX",
    "code3": "MEX",
    "continent": "NA",
    "tld": "mx",
    "phone": "52",
    "name": "Mexico"
  },
  {
    "id": 161,
    "name_ascii": "Malaysia",
    "slug": "malaysia",
    "geoname_id": 1733045,
    "alternate_names": "Малайзия",
    "code2": "MY",
    "code3": "MYS",
    "continent": "AS",
    "tld": "my",
    "phone": "60",
    "name": "Malaysia"
  },
  {
    "id": 162,
    "name_ascii": "Mozambique",
    "slug": "mozambique",
    "geoname_id": 1036973,
    "alternate_names": "Republic of Mozambique;Мозамбик",
    "code2": "MZ",
    "code3": "MOZ",
    "continent": "AF",
    "tld": "mz",
    "phone": "258",
    "name": "Mozambique"
  },
  {
    "id": 163,
    "name_ascii": "Namibia",
    "slug": "namibia",
    "geoname_id": 3355338,
    "alternate_names": "Намибия",
    "code2": "NA",
    "code3": "NAM",
    "continent": "AF",
    "tld": "na",
    "phone": "264",
    "name": "Namibia"
  },
  {
    "id": 164,
    "name_ascii": "New Caledonia",
    "slug": "new-caledonia",
    "geoname_id": 2139685,
    "alternate_names": "Новая Каледония",
    "code2": "NC",
    "code3": "NCL",
    "continent": "OC",
    "tld": "nc",
    "phone": "687",
    "name": "New Caledonia"
  },
  {
    "id": 165,
    "name_ascii": "Niger",
    "slug": "niger",
    "geoname_id": 2440476,
    "alternate_names": "Republic of Niger;Нигер",
    "code2": "NE",
    "code3": "NER",
    "continent": "AF",
    "tld": "ne",
    "phone": "227",
    "name": "Niger"
  },
  {
    "id": 166,
    "name_ascii": "Norfolk Island",
    "slug": "norfolk-island",
    "geoname_id": 2155115,
    "alternate_names": "Остров Норфолк",
    "code2": "NF",
    "code3": "NFK",
    "continent": "OC",
    "tld": "nf",
    "phone": "672",
    "name": "Norfolk Island"
  },
  {
    "id": 167,
    "name_ascii": "Nigeria",
    "slug": "nigeria",
    "geoname_id": 2328926,
    "alternate_names": "Нигерия",
    "code2": "NG",
    "code3": "NGA",
    "continent": "AF",
    "tld": "ng",
    "phone": "234",
    "name": "Nigeria"
  },
  {
    "id": 168,
    "name_ascii": "Nicaragua",
    "slug": "nicaragua",
    "geoname_id": 3617476,
    "alternate_names": "Republic of Nicaragua;Никарагуа",
    "code2": "NI",
    "code3": "NIC",
    "continent": "NA",
    "tld": "ni",
    "phone": "505",
    "name": "Nicaragua"
  },
  {
    "id": 169,
    "name_ascii": "Netherlands",
    "slug": "netherlands",
    "geoname_id": 2750405,
    "alternate_names": "Holland;Kingdom of the Netherlands;The Netherlands;Нидерланды",
    "code2": "NL",
    "code3": "NLD",
    "continent": "EU",
    "tld": "nl",
    "phone": "31",
    "name": "Netherlands"
  },
  {
    "id": 170,
    "name_ascii": "Norway",
    "slug": "norway",
    "geoname_id": 3144096,
    "alternate_names": "Kingdom of Norway;Норвегия",
    "code2": "NO",
    "code3": "NOR",
    "continent": "EU",
    "tld": "no",
    "phone": "47",
    "name": "Norway"
  },
  {
    "id": 171,
    "name_ascii": "Nepal",
    "slug": "nepal",
    "geoname_id": 1282988,
    "alternate_names": "Federal Democratic Republic of Nepal;Непал",
    "code2": "NP",
    "code3": "NPL",
    "continent": "AS",
    "tld": "np",
    "phone": "977",
    "name": "Nepal"
  },
  {
    "id": 172,
    "name_ascii": "Nauru",
    "slug": "nauru",
    "geoname_id": 2110425,
    "alternate_names": "Republic of Nauru;Науру",
    "code2": "NR",
    "code3": "NRU",
    "continent": "OC",
    "tld": "nr",
    "phone": "674",
    "name": "Nauru"
  },
  {
    "id": 173,
    "name_ascii": "Niue",
    "slug": "niue",
    "geoname_id": 4036232,
    "alternate_names": "Ниуе;Ниуэ",
    "code2": "NU",
    "code3": "NIU",
    "continent": "OC",
    "tld": "nu",
    "phone": "683",
    "name": "Niue"
  },
  {
    "id": 174,
    "name_ascii": "New Zealand",
    "slug": "new-zealand",
    "geoname_id": 2186224,
    "alternate_names": "Новая Зеландия",
    "code2": "NZ",
    "code3": "NZL",
    "continent": "OC",
    "tld": "nz",
    "phone": "64",
    "name": "New Zealand"
  },
  {
    "id": 175,
    "name_ascii": "Oman",
    "slug": "oman",
    "geoname_id": 286963,
    "alternate_names": "Sultanate of Oman;Оман",
    "code2": "OM",
    "code3": "OMN",
    "continent": "AS",
    "tld": "om",
    "phone": "968",
    "name": "Oman"
  },
  {
    "id": 176,
    "name_ascii": "Panama",
    "slug": "panama",
    "geoname_id": 3703430,
    "alternate_names": "Republic of Panama;Панама",
    "code2": "PA",
    "code3": "PAN",
    "continent": "NA",
    "tld": "pa",
    "phone": "507",
    "name": "Panama"
  },
  {
    "id": 177,
    "name_ascii": "Peru",
    "slug": "peru",
    "geoname_id": 3932488,
    "alternate_names": "Republic of Peru;Перу",
    "code2": "PE",
    "code3": "PER",
    "continent": "SA",
    "tld": "pe",
    "phone": "51",
    "name": "Peru"
  },
  {
    "id": 178,
    "name_ascii": "French Polynesia",
    "slug": "french-polynesia",
    "geoname_id": 4030656,
    "alternate_names": "Французская Полинезия",
    "code2": "PF",
    "code3": "PYF",
    "continent": "OC",
    "tld": "pf",
    "phone": "689",
    "name": "French Polynesia"
  },
  {
    "id": 179,
    "name_ascii": "Papua New Guinea",
    "slug": "papua-new-guinea",
    "geoname_id": 2088628,
    "alternate_names": "Папуа – Новая Гвинея;Папуа — Новая Гвинея",
    "code2": "PG",
    "code3": "PNG",
    "continent": "OC",
    "tld": "pg",
    "phone": "675",
    "name": "Papua New Guinea"
  },
  {
    "id": 180,
    "name_ascii": "Philippines",
    "slug": "philippines",
    "geoname_id": 1694008,
    "alternate_names": "Republic of the Philippines;Филиппины",
    "code2": "PH",
    "code3": "PHL",
    "continent": "AS",
    "tld": "ph",
    "phone": "63",
    "name": "Philippines"
  },
  {
    "id": 181,
    "name_ascii": "Pakistan",
    "slug": "pakistan",
    "geoname_id": 1168579,
    "alternate_names": "Islamic Republic of Pakistan;Пакистан",
    "code2": "PK",
    "code3": "PAK",
    "continent": "AS",
    "tld": "pk",
    "phone": "92",
    "name": "Pakistan"
  },
  {
    "id": 182,
    "name_ascii": "Poland",
    "slug": "poland",
    "geoname_id": 798544,
    "alternate_names": "Republic of Poland;Польша",
    "code2": "PL",
    "code3": "POL",
    "continent": "EU",
    "tld": "pl",
    "phone": "48",
    "name": "Poland"
  },
  {
    "id": 183,
    "name_ascii": "Saint Pierre and Miquelon",
    "slug": "saint-pierre-and-miquelon",
    "geoname_id": 3424932,
    "alternate_names": "Сен-Пьер и Микелон",
    "code2": "PM",
    "code3": "SPM",
    "continent": "NA",
    "tld": "pm",
    "phone": "508",
    "name": "Saint Pierre and Miquelon"
  },
  {
    "id": 184,
    "name_ascii": "Pitcairn",
    "slug": "pitcairn",
    "geoname_id": 4030699,
    "alternate_names": "Pitcairn Islands;Питкэрн",
    "code2": "PN",
    "code3": "PCN",
    "continent": "OC",
    "tld": "pn",
    "phone": "870",
    "name": "Pitcairn"
  },
  {
    "id": 185,
    "name_ascii": "Puerto Rico",
    "slug": "puerto-rico",
    "geoname_id": 4566966,
    "alternate_names": "Commonwealth of Puerto Rico;Пуэрто-Рико",
    "code2": "PR",
    "code3": "PRI",
    "continent": "NA",
    "tld": "pr",
    "phone": "1-787 and 1-939",
    "name": "Puerto Rico"
  },
  {
    "id": 186,
    "name_ascii": "Palestinian Territory",
    "slug": "palestinian-territory",
    "geoname_id": 6254930,
    "alternate_names": "Palestinian Territories;Palestinian Territory (the Occupied);Palestinian Territory, Occupied;the Occupied Palestinian Territory;Палестинские территории",
    "code2": "PS",
    "code3": "PSE",
    "continent": "AS",
    "tld": "ps",
    "phone": "970",
    "name": "Palestinian Territory"
  },
  {
    "id": 187,
    "name_ascii": "Portugal",
    "slug": "portugal",
    "geoname_id": 2264397,
    "alternate_names": "Portuguese Republic;Португалия",
    "code2": "PT",
    "code3": "PRT",
    "continent": "EU",
    "tld": "pt",
    "phone": "351",
    "name": "Portugal"
  },
  {
    "id": 188,
    "name_ascii": "Palau",
    "slug": "palau",
    "geoname_id": 1559582,
    "alternate_names": "Палау",
    "code2": "PW",
    "code3": "PLW",
    "continent": "OC",
    "tld": "pw",
    "phone": "680",
    "name": "Palau"
  },
  {
    "id": 189,
    "name_ascii": "Paraguay",
    "slug": "paraguay",
    "geoname_id": 3437598,
    "alternate_names": "Republic of Paraguay;Парагвай",
    "code2": "PY",
    "code3": "PRY",
    "continent": "SA",
    "tld": "py",
    "phone": "595",
    "name": "Paraguay"
  },
  {
    "id": 190,
    "name_ascii": "Qatar",
    "slug": "qatar",
    "geoname_id": 289688,
    "alternate_names": "State of Qatar;Катар",
    "code2": "QA",
    "code3": "QAT",
    "continent": "AS",
    "tld": "qa",
    "phone": "974",
    "name": "Qatar"
  },
  {
    "id": 191,
    "name_ascii": "Reunion",
    "slug": "reunion",
    "geoname_id": 935317,
    "alternate_names": "Réunion;Реюньон",
    "code2": "RE",
    "code3": "REU",
    "continent": "AF",
    "tld": "re",
    "phone": "262",
    "name": "Reunion"
  },
  {
    "id": 192,
    "name_ascii": "Romania",
    "slug": "romania",
    "geoname_id": 798549,
    "alternate_names": "Румыния",
    "code2": "RO",
    "code3": "ROU",
    "continent": "EU",
    "tld": "ro",
    "phone": "40",
    "name": "Romania"
  },
  {
    "id": 193,
    "name_ascii": "Serbia",
    "slug": "serbia",
    "geoname_id": 6290252,
    "alternate_names": "Сербия",
    "code2": "RS",
    "code3": "SRB",
    "continent": "EU",
    "tld": "rs",
    "phone": "381",
    "name": "Serbia"
  },
  {
    "id": 194,
    "name_ascii": "Russia",
    "slug": "russia",
    "geoname_id": 2017370,
    "alternate_names": "Russian Federation;Российская Федерация",
    "code2": "RU",
    "code3": "RUS",
    "continent": "EU",
    "tld": "ru",
    "phone": "7",
    "name": "Russia"
  },
  {
    "id": 195,
    "name_ascii": "Rwanda",
    "slug": "rwanda",
    "geoname_id": 49518,
    "alternate_names": "Republic of Rwanda;Руанда",
    "code2": "RW",
    "code3": "RWA",
    "continent": "AF",
    "tld": "rw",
    "phone": "250",
    "name": "Rwanda"
  },
  {
    "id": 196,
    "name_ascii": "Saudi Arabia",
    "slug": "saudi-arabia",
    "geoname_id": 102358,
    "alternate_names": "Kingdom of Saudi Arabia;Саудовская Аравия",
    "code2": "SA",
    "code3": "SAU",
    "continent": "AS",
    "tld": "sa",
    "phone": "966",
    "name": "Saudi Arabia"
  },
  {
    "id": 197,
    "name_ascii": "Solomon Islands",
    "slug": "solomon-islands",
    "geoname_id": 2103350,
    "alternate_names": "Соломоновы Острова;Соломонские острова",
    "code2": "SB",
    "code3": "SLB",
    "continent": "OC",
    "tld": "sb",
    "phone": "677",
    "name": "Solomon Islands"
  },
  {
    "id": 198,
    "name_ascii": "Seychelles",
    "slug": "seychelles",
    "geoname_id": 241170,
    "alternate_names": "Сейшельские Острова;Сейшельские о-ва",
    "code2": "SC",
    "code3": "SYC",
    "continent": "AF",
    "tld": "sc",
    "phone": "248",
    "name": "Seychelles"
  },
  {
    "id": 199,
    "name_ascii": "Sudan",
    "slug": "sudan",
    "geoname_id": 366755,
    "alternate_names": "Судан",
    "code2": "SD",
    "code3": "SDN",
    "continent": "AF",
    "tld": "sd",
    "phone": "249",
    "name": "Sudan"
  },
  {
    "id": 200,
    "name_ascii": "South Sudan",
    "slug": "south-sudan",
    "geoname_id": 7909807,
    "alternate_names": "Republic of South Sudan",
    "code2": "SS",
    "code3": "SSD",
    "continent": "AF",
    "tld": "",
    "phone": "211",
    "name": "South Sudan"
  },
  {
    "id": 201,
    "name_ascii": "Sweden",
    "slug": "sweden",
    "geoname_id": 2661886,
    "alternate_names": "Kingdom of Sweden;Швеция",
    "code2": "SE",
    "code3": "SWE",
    "continent": "EU",
    "tld": "se",
    "phone": "46",
    "name": "Sweden"
  },
  {
    "id": 202,
    "name_ascii": "Singapore",
    "slug": "singapore",
    "geoname_id": 1880251,
    "alternate_names": "Сингапур",
    "code2": "SG",
    "code3": "SGP",
    "continent": "AS",
    "tld": "sg",
    "phone": "65",
    "name": "Singapore"
  },
  {
    "id": 203,
    "name_ascii": "Saint Helena",
    "slug": "saint-helena",
    "geoname_id": 3370751,
    "alternate_names": "Saint Helena, Ascension and Tristan Da Cunha;Остров Святой Елены",
    "code2": "SH",
    "code3": "SHN",
    "continent": "AF",
    "tld": "sh",
    "phone": "290",
    "name": "Saint Helena"
  },
  {
    "id": 204,
    "name_ascii": "Slovenia",
    "slug": "slovenia",
    "geoname_id": 3190538,
    "alternate_names": "Republic of Slovenia;Словения",
    "code2": "SI",
    "code3": "SVN",
    "continent": "EU",
    "tld": "si",
    "phone": "386",
    "name": "Slovenia"
  },
  {
    "id": 205,
    "name_ascii": "Svalbard and Jan Mayen",
    "slug": "svalbard-and-jan-mayen",
    "geoname_id": 607072,
    "alternate_names": "Свальбард и Ян-Майен",
    "code2": "SJ",
    "code3": "SJM",
    "continent": "EU",
    "tld": "sj",
    "phone": "47",
    "name": "Svalbard and Jan Mayen"
  },
  {
    "id": 206,
    "name_ascii": "Slovakia",
    "slug": "slovakia",
    "geoname_id": 3057568,
    "alternate_names": "Slovak Republic;Словакия;Словацкая республика",
    "code2": "SK",
    "code3": "SVK",
    "continent": "EU",
    "tld": "sk",
    "phone": "421",
    "name": "Slovakia"
  },
  {
    "id": 207,
    "name_ascii": "Sierra Leone",
    "slug": "sierra-leone",
    "geoname_id": 2403846,
    "alternate_names": "Сьерра-Леоне",
    "code2": "SL",
    "code3": "SLE",
    "continent": "AF",
    "tld": "sl",
    "phone": "232",
    "name": "Sierra Leone"
  },
  {
    "id": 208,
    "name_ascii": "San Marino",
    "slug": "san-marino",
    "geoname_id": 3168068,
    "alternate_names": "Сан-Марино",
    "code2": "SM",
    "code3": "SMR",
    "continent": "EU",
    "tld": "sm",
    "phone": "378",
    "name": "San Marino"
  },
  {
    "id": 209,
    "name_ascii": "Senegal",
    "slug": "senegal",
    "geoname_id": 2245662,
    "alternate_names": "Republic of Senegal;Сенегал",
    "code2": "SN",
    "code3": "SEN",
    "continent": "AF",
    "tld": "sn",
    "phone": "221",
    "name": "Senegal"
  },
  {
    "id": 210,
    "name_ascii": "Somalia",
    "slug": "somalia",
    "geoname_id": 51537,
    "alternate_names": "Federal Republic of Somalia;The Somali Republic;Сомали",
    "code2": "SO",
    "code3": "SOM",
    "continent": "AF",
    "tld": "so",
    "phone": "252",
    "name": "Somalia"
  },
  {
    "id": 211,
    "name_ascii": "Suriname",
    "slug": "suriname",
    "geoname_id": 3382998,
    "alternate_names": "Republic of Suriname;Суринам",
    "code2": "SR",
    "code3": "SUR",
    "continent": "SA",
    "tld": "sr",
    "phone": "597",
    "name": "Suriname"
  },
  {
    "id": 212,
    "name_ascii": "Sao Tome and Principe",
    "slug": "sao-tome-and-principe",
    "geoname_id": 2410758,
    "alternate_names": "Democratic Republic of Sao Tome and Principe;Сан-Томе и Принсипе;Сан-Томе и Принсипи",
    "code2": "ST",
    "code3": "STP",
    "continent": "AF",
    "tld": "st",
    "phone": "239",
    "name": "Sao Tome and Principe"
  },
  {
    "id": 213,
    "name_ascii": "El Salvador",
    "slug": "el-salvador",
    "geoname_id": 3585968,
    "alternate_names": "Republic of El Salvador;Сальвадор",
    "code2": "SV",
    "code3": "SLV",
    "continent": "NA",
    "tld": "sv",
    "phone": "503",
    "name": "El Salvador"
  },
  {
    "id": 214,
    "name_ascii": "Sint Maarten",
    "slug": "sint-maarten",
    "geoname_id": 7609695,
    "alternate_names": "Country of Sint Maarten;Sint Maarten (Dutch Part);Синт-Мартен",
    "code2": "SX",
    "code3": "SXM",
    "continent": "NA",
    "tld": "sx",
    "phone": "599",
    "name": "Sint Maarten"
  },
  {
    "id": 215,
    "name_ascii": "Syria",
    "slug": "syria",
    "geoname_id": 163843,
    "alternate_names": "Syrian Arab Republic;Сирийская Арабская Республика;Сирия",
    "code2": "SY",
    "code3": "SYR",
    "continent": "AS",
    "tld": "sy",
    "phone": "963",
    "name": "Syria"
  },
  {
    "id": 216,
    "name_ascii": "Swaziland",
    "slug": "swaziland",
    "geoname_id": 934841,
    "alternate_names": "Eswatini;Свазиленд",
    "code2": "SZ",
    "code3": "SWZ",
    "continent": "AF",
    "tld": "sz",
    "phone": "268",
    "name": "Swaziland"
  },
  {
    "id": 217,
    "name_ascii": "Turks and Caicos Islands",
    "slug": "turks-and-caicos-islands",
    "geoname_id": 3576916,
    "alternate_names": "Острова Тёркс и Кайкос",
    "code2": "TC",
    "code3": "TCA",
    "continent": "NA",
    "tld": "tc",
    "phone": "1-649",
    "name": "Turks and Caicos Islands"
  },
  {
    "id": 218,
    "name_ascii": "Chad",
    "slug": "chad",
    "geoname_id": 2434508,
    "alternate_names": "Republic of Chad;Чад",
    "code2": "TD",
    "code3": "TCD",
    "continent": "AF",
    "tld": "td",
    "phone": "235",
    "name": "Chad"
  },
  {
    "id": 219,
    "name_ascii": "French Southern Territories",
    "slug": "french-southern-territories",
    "geoname_id": 1546748,
    "alternate_names": "Французские Южные Территории",
    "code2": "TF",
    "code3": "ATF",
    "continent": "AN",
    "tld": "tf",
    "phone": "",
    "name": "French Southern Territories"
  },
  {
    "id": 220,
    "name_ascii": "Togo",
    "slug": "togo",
    "geoname_id": 2363686,
    "alternate_names": "Togolese Republic;Того",
    "code2": "TG",
    "code3": "TGO",
    "continent": "AF",
    "tld": "tg",
    "phone": "228",
    "name": "Togo"
  },
  {
    "id": 221,
    "name_ascii": "Thailand",
    "slug": "thailand",
    "geoname_id": 1605651,
    "alternate_names": "Kingdom of Thailand;Таиланд;Тайланд",
    "code2": "TH",
    "code3": "THA",
    "continent": "AS",
    "tld": "th",
    "phone": "66",
    "name": "Thailand"
  },
  {
    "id": 222,
    "name_ascii": "Tajikistan",
    "slug": "tajikistan",
    "geoname_id": 1220409,
    "alternate_names": "Republic of Tajikistan;Таджикистан",
    "code2": "TJ",
    "code3": "TJK",
    "continent": "AS",
    "tld": "tj",
    "phone": "992",
    "name": "Tajikistan"
  },
  {
    "id": 223,
    "name_ascii": "Tokelau",
    "slug": "tokelau",
    "geoname_id": 4031074,
    "alternate_names": "Токелау",
    "code2": "TK",
    "code3": "TKL",
    "continent": "OC",
    "tld": "tk",
    "phone": "690",
    "name": "Tokelau"
  },
  {
    "id": 224,
    "name_ascii": "Timor Leste",
    "slug": "timor-leste",
    "geoname_id": 1966436,
    "alternate_names": "Democratic Republic of Timor-Leste;East Timor;Timor-Leste;Восточный Тимор",
    "code2": "TL",
    "code3": "TLS",
    "continent": "OC",
    "tld": "tl",
    "phone": "670",
    "name": "Timor Leste"
  },
  {
    "id": 225,
    "name_ascii": "Turkmenistan",
    "slug": "turkmenistan",
    "geoname_id": 1218197,
    "alternate_names": "Туркменистан;Туркмения",
    "code2": "TM",
    "code3": "TKM",
    "continent": "AS",
    "tld": "tm",
    "phone": "993",
    "name": "Turkmenistan"
  },
  {
    "id": 226,
    "name_ascii": "Tunisia",
    "slug": "tunisia",
    "geoname_id": 2464461,
    "alternate_names": "Tunisian Republic;Тунис",
    "code2": "TN",
    "code3": "TUN",
    "continent": "AF",
    "tld": "tn",
    "phone": "216",
    "name": "Tunisia"
  },
  {
    "id": 227,
    "name_ascii": "Tonga",
    "slug": "tonga",
    "geoname_id": 4032283,
    "alternate_names": "Тонга",
    "code2": "TO",
    "code3": "TON",
    "continent": "OC",
    "tld": "to",
    "phone": "676",
    "name": "Tonga"
  },
  {
    "id": 228,
    "name_ascii": "Turkey",
    "slug": "turkey",
    "geoname_id": 298795,
    "alternate_names": "Republic of Turkey;Турция",
    "code2": "TR",
    "code3": "TUR",
    "continent": "AS",
    "tld": "tr",
    "phone": "90",
    "name": "Turkey"
  },
  {
    "id": 229,
    "name_ascii": "Trinidad and Tobago",
    "slug": "trinidad-and-tobago",
    "geoname_id": 3573591,
    "alternate_names": "Тринидад и Тобаго",
    "code2": "TT",
    "code3": "TTO",
    "continent": "NA",
    "tld": "tt",
    "phone": "1-868",
    "name": "Trinidad and Tobago"
  },
  {
    "id": 230,
    "name_ascii": "Tuvalu",
    "slug": "tuvalu",
    "geoname_id": 2110297,
    "alternate_names": "Тувалу",
    "code2": "TV",
    "code3": "TUV",
    "continent": "OC",
    "tld": "tv",
    "phone": "688",
    "name": "Tuvalu"
  },
  {
    "id": 231,
    "name_ascii": "Taiwan",
    "slug": "taiwan",
    "geoname_id": 1668284,
    "alternate_names": "Тайвань",
    "code2": "TW",
    "code3": "TWN",
    "continent": "AS",
    "tld": "tw",
    "phone": "886",
    "name": "Taiwan"
  },
  {
    "id": 232,
    "name_ascii": "Tanzania",
    "slug": "tanzania",
    "geoname_id": 149590,
    "alternate_names": "Танзания",
    "code2": "TZ",
    "code3": "TZA",
    "continent": "AF",
    "tld": "tz",
    "phone": "255",
    "name": "Tanzania"
  },
  {
    "id": 233,
    "name_ascii": "Ukraine",
    "slug": "ukraine",
    "geoname_id": 690791,
    "alternate_names": "Украина",
    "code2": "UA",
    "code3": "UKR",
    "continent": "EU",
    "tld": "ua",
    "phone": "380",
    "name": "Ukraine"
  },
  {
    "id": 234,
    "name_ascii": "Uganda",
    "slug": "uganda",
    "geoname_id": 226074,
    "alternate_names": "Уганда",
    "code2": "UG",
    "code3": "UGA",
    "continent": "AF",
    "tld": "ug",
    "phone": "256",
    "name": "Uganda"
  },
  {
    "id": 235,
    "name_ascii": "United States Minor Outlying Islands",
    "slug": "united-states-minor-outlying-islands",
    "geoname_id": 5854968,
    "alternate_names": "U.S. Minor Outlying Islands;Внешние малые острова (США)",
    "code2": "UM",
    "code3": "UMI",
    "continent": "OC",
    "tld": "um",
    "phone": "1",
    "name": "United States Minor Outlying Islands"
  },
  {
    "id": 236,
    "name_ascii": "United States",
    "slug": "united-states",
    "geoname_id": 6252001,
    "alternate_names": "America;United States of America;США;Соединенные Штаты",
    "code2": "US",
    "code3": "USA",
    "continent": "NA",
    "tld": "us",
    "phone": "1",
    "name": "United States"
  },
  {
    "id": 237,
    "name_ascii": "Uruguay",
    "slug": "uruguay",
    "geoname_id": 3439705,
    "alternate_names": "Oriental Republic of Uruguay;Уругвай",
    "code2": "UY",
    "code3": "URY",
    "continent": "SA",
    "tld": "uy",
    "phone": "598",
    "name": "Uruguay"
  },
  {
    "id": 238,
    "name_ascii": "Uzbekistan",
    "slug": "uzbekistan",
    "geoname_id": 1512440,
    "alternate_names": "Republic of Uzbekistan;Узбекистан",
    "code2": "UZ",
    "code3": "UZB",
    "continent": "AS",
    "tld": "uz",
    "phone": "998",
    "name": "Uzbekistan"
  },
  {
    "id": 239,
    "name_ascii": "Vatican",
    "slug": "vatican",
    "geoname_id": 3164670,
    "alternate_names": "Holy See;Holy See (Vatican City State);Vatican City State;Vatican City State (Holy See);Vatican Hill;Ватикан;Государство-город Ватикан",
    "code2": "VA",
    "code3": "VAT",
    "continent": "EU",
    "tld": "va",
    "phone": "379",
    "name": "Vatican"
  },
  {
    "id": 240,
    "name_ascii": "Saint Vincent and the Grenadines",
    "slug": "saint-vincent-and-the-grenadines",
    "geoname_id": 3577815,
    "alternate_names": "St Vincent and Grenadines;Сент-Винсент и Гренадины",
    "code2": "VC",
    "code3": "VCT",
    "continent": "NA",
    "tld": "vc",
    "phone": "1-784",
    "name": "Saint Vincent and the Grenadines"
  },
  {
    "id": 241,
    "name_ascii": "Venezuela",
    "slug": "venezuela",
    "geoname_id": 3625428,
    "alternate_names": "Bolivarian Republic of Venezuela;Republic of Venezuela;United States of Venezuela;Venezuela, Bolivarian Republic Of;Венесуэла",
    "code2": "VE",
    "code3": "VEN",
    "continent": "SA",
    "tld": "ve",
    "phone": "58",
    "name": "Venezuela"
  },
  {
    "id": 242,
    "name_ascii": "British Virgin Islands",
    "slug": "british-virgin-islands",
    "geoname_id": 3577718,
    "alternate_names": "Virgin Islands (British);Британские Виргинские о-ва;Виргинские Острова",
    "code2": "VG",
    "code3": "VGB",
    "continent": "NA",
    "tld": "vg",
    "phone": "1-284",
    "name": "British Virgin Islands"
  },
  {
    "id": 243,
    "name_ascii": "U.S. Virgin Islands",
    "slug": "us-virgin-islands",
    "geoname_id": 4796775,
    "alternate_names": "Virgin Islands (US);Виргинские о-ва (США)",
    "code2": "VI",
    "code3": "VIR",
    "continent": "NA",
    "tld": "vi",
    "phone": "1-340",
    "name": "U.S. Virgin Islands"
  },
  {
    "id": 244,
    "name_ascii": "Vietnam",
    "slug": "vietnam",
    "geoname_id": 1562822,
    "alternate_names": "Socialist Republic of Vietnam;Вьетнам",
    "code2": "VN",
    "code3": "VNM",
    "continent": "AS",
    "tld": "vn",
    "phone": "84",
    "name": "Vietnam"
  },
  {
    "id": 245,
    "name_ascii": "Vanuatu",
    "slug": "vanuatu",
    "geoname_id": 2134431,
    "alternate_names": "Republic of Vanuatu;Вануату",
    "code2": "VU",
    "code3": "VUT",
    "continent": "OC",
    "tld": "vu",
    "phone": "678",
    "name": "Vanuatu"
  },
  {
    "id": 246,
    "name_ascii": "Wallis and Futuna",
    "slug": "wallis-and-futuna",
    "geoname_id": 4034749,
    "alternate_names": "Острова Уоллис и Футуна;Уоллис и Футуна",
    "code2": "WF",
    "code3": "WLF",
    "continent": "OC",
    "tld": "wf",
    "phone": "681",
    "name": "Wallis and Futuna"
  },
  {
    "id": 247,
    "name_ascii": "Samoa",
    "slug": "samoa",
    "geoname_id": 4034894,
    "alternate_names": "Independent State of Samoa;Самоа",
    "code2": "WS",
    "code3": "WSM",
    "continent": "OC",
    "tld": "ws",
    "phone": "685",
    "name": "Samoa"
  },
  {
    "id": 248,
    "name_ascii": "Yemen",
    "slug": "yemen",
    "geoname_id": 69543,
    "alternate_names": "Republic of Yemen;Йемен",
    "code2": "YE",
    "code3": "YEM",
    "continent": "AS",
    "tld": "ye",
    "phone": "967",
    "name": "Yemen"
  },
  {
    "id": 249,
    "name_ascii": "Mayotte",
    "slug": "mayotte",
    "geoname_id": 1024031,
    "alternate_names": "Майотта",
    "code2": "YT",
    "code3": "MYT",
    "continent": "AF",
    "tld": "yt",
    "phone": "262",
    "name": "Mayotte"
  },
  {
    "id": 250,
    "name_ascii": "South Africa",
    "slug": "south-africa",
    "geoname_id": 953987,
    "alternate_names": "Republic of South Africa;ЮАР;Южно-Африканская Республика",
    "code2": "ZA",
    "code3": "ZAF",
    "continent": "AF",
    "tld": "za",
    "phone": "27",
    "name": "South Africa"
  },
  {
    "id": 251,
    "name_ascii": "Zambia",
    "slug": "zambia",
    "geoname_id": 895949,
    "alternate_names": "Republic of Zambia;Замбия",
    "code2": "ZM",
    "code3": "ZMB",
    "continent": "AF",
    "tld": "zm",
    "phone": "260",
    "name": "Zambia"
  },
  {
    "id": 252,
    "name_ascii": "Zimbabwe",
    "slug": "zimbabwe",
    "geoname_id": 878675,
    "alternate_names": "Зимбабве",
    "code2": "ZW",
    "code3": "ZWE",
    "continent": "AF",
    "tld": "zw",
    "phone": "263",
    "name": "Zimbabwe"
  },
  {
    "id": 253,
    "name_ascii": "Serbia and Montenegro",
    "slug": "serbia-and-montenegro",
    "geoname_id": 8505033,
    "alternate_names": "Federal Republic of Yugoslavia;State Union of Serbia and Montenegro",
    "code2": "CS",
    "code3": "SCG",
    "continent": "EU",
    "tld": "cs",
    "phone": "381",
    "name": "Serbia and Montenegro"
  },
  {
    "id": 254,
    "name_ascii": "Netherlands Antilles",
    "slug": "netherlands-antilles",
    "geoname_id": 8505032,
    "alternate_names": "",
    "code2": "AN",
    "code3": "ANT",
    "continent": "NA",
    "tld": "an",
    "phone": "599",
    "name": "Netherlands Antilles"
  }
]


def load_stores(apps, schema_editor):
    Country = apps.get_model("cities_light", "Country")

    Country.objects.all().delete()

    for item in DATA:
        item.pop('id')
        country_corporate = Country(**item)
        country_corporate.save()


class Migration(migrations.Migration):

    dependencies = [
        ('stem_registration', '0003_auto_20181031_1302'),
    ]

    operations = [
        migrations.RunPython(load_stores),
    ]



from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="stem_registration",
    version="0.0.39",
    author="Dmitry Shevelev",
    author_email="shevelev.dmitriy@stemsc.com",
    description="A small registration package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.stemsc.com/shevelev/registration",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'django>=1.11,<2',
        'Pillow>=5.3.0',
        'django-registration-redux>=2.4,<=2.4',
        'django-bootstrap4>=0.0.6,<=0.0.6',
        'django-cities-light>=3.5.0,<=3.5.0',
        'django-select2>=6.3.1,<=6.3.1',
    ]
)



import uuid

from cities_light.models import Country
from django.conf import settings
from django.contrib.auth.models import User
from django.test import Client, TestCase, override_settings
from django.urls import reverse

from stem_registration.models import RegistrationData


class TestRegistrationViewStem(TestCase):
    client = Client()

    username = ('test_%s' % uuid.uuid1())[:12]
    email = '%s@mailinator.com' % username

    @classmethod
    def setUpTestData(cls):
        # теперь страна создается миграцией
        cls.country = Country.objects.get(code3='USA')
        print("setUpTestData: Run once to set up non-modified data for all class methods.")

    def setUp(self):
        print("setUp: Run once for every test method to setup clean data.")

    def test_get(self):
        response = self.client.get(reverse('stem_register'))
        self.assertEquals(response.status_code, 200)

    def test_post(self):
        data = {
            'username': self.username,
            'password1': 'TopSecretPass!1',
            'password2': 'TopSecretPass!1',
            'number': '+10955217581',
            'email': self.email,
            'first_name': 'Dmitriy',
            'last_name': 'Shevelev',
            'contractor_type': 'PP',
            'tax_number': self.username[:10],  # ИНН
            'accounting_number': self.username,  # ЕГРПОУ
            'file1': '', 'file2': '', 'file3': '', 'file4': '', 'file5': '',
            'address': 'biblika 1g',
            'address_optional': '',
            'city': 'Kharkiv',
            'country': self.country.id,
            'zip': '5622',
            'same': 'on',
            'billing_address': 'biblika 1g',
            'bill_address_optional': 'biblika 1g',
            'bill_city': '', 'bill_zip': '', 'agree': 'on',
            'name_legal': 'ООО ООО',
        }
        response = self.client.post(reverse('stem_register'), data=data)

        self.assertEquals(response.status_code, 302)

        try:
            user = User.objects.get(username=data['username'])
        except User.DoesNotExist:
            self.fail('User is not created')

        self.assertFalse(user.is_active)

        try:
            data = RegistrationData.objects.get(user=user)
        except RegistrationData.DoesNotExist:
            self.fail('RegistrationData is not created')

        print(data)

    @override_settings(
        SHOW_LOGIN=False,
        SHOW_LAST_FIRST_NAME=False,
        SHOW_CONTRACTOR_TYPE=False,
        SHOW_ADDRESS=False,
        SHOW_BILLING_ADDRESS=False,
        SHOW_NUMBER=False,
        SHOW_TAX_NUMBER=False,
        SHOW_ID_CARD_FIELDS=False,
        SHOW_NAME_LEGAL=False,
        SHOW_ACCOUNTING_NUMBER=False,
    )
    def test_only_email(self):

        data = {
            'username': '',
            'password1': 'TopSecretPass!1',
            'password2': 'TopSecretPass!1',
            # 'number': '+10955217581',
            'email': self.email,
        }
        response = self.client.post(reverse('stem_register'), data=data)

        self.assertEquals(response.status_code, 302)

        try:
            user = User.objects.get(username=data['email'])
        except User.DoesNotExist:
            self.fail('User is not created')

        try:
            data = RegistrationData.objects.get(user=user)
        except RegistrationData.DoesNotExist:
            self.fail('RegistrationData is not created')

        print(data)
